@@ -61,7 +61,7 @@ OC.L10N.register(
     "Copied {origin} inside {destination}" : "منسوخ {origin} داخل {destination}",
     "Copied {origin} and {nbfiles} other files inside {destination}" : "منسوخ {origin} و {nbfiles} ملفات اخرى داخل {destination}",
     "Failed to redirect to client" : "فشل في التحويل الى العميل",
-    "{newName} already exists" : "{newname} موجود مسبقاً",
+    "{newName} already exists" : "{newName} موجود مسبقاً",
     "Could not rename \"{fileName}\", it does not exist any more" : "لا يمكن اعادة تسمية \"{fileName}\", لأنه لم يعد موجود",
     "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "الاسم \"{targetName}\" مستخدم من قبل في المجلد \"{dir}\". الرجاء اختيار اسم اخر.",
     "Could not rename \"{fileName}\"" : "إعادة تسمية الملف \"{fileName}\" لم تنجح",
@@ -84,7 +84,7 @@ OC.L10N.register(
     "New" : "جديد",
     "New file/folder menu" : "قائمة مجلد/ملف جديد",
     "Select file range" : "حدد نطاق الملف",
-    "{used}%" : "{مُستخدَم}%",
+    "{used}%" : "{used}%",
     "{used} of {quota} used" : "{used} من {quota} مستخدم",
     "{used} used" : "{used} مستخدم",
     "\"{name}\" is an invalid file name." : "\"{name}\" اسم ملف غير صالح للاستخدام .",
@@ -156,11 +156,20 @@ OC.L10N.register(
     "A file has been added to or removed from your <strong>favorites</strong>" : "ملف اضيف إلى او تم ازالته من <strong> مفضلتك </strong>",
     "A file or folder has been <strong>changed</strong>" : "تم  <strong> تغيير</strong> ملف أو مجلد",
     "A favorite file or folder has been <strong>changed</strong>" : "ملف في المفضلة تم <strong>تم تغييره</strong>",
+    "Failed to authorize" : "فشل في التخويل",
+    "Invalid folder path" : "مسار المجلد غير صحيح",
+    "Folder not found" : "المجلد غير موجود",
     "Upload (max. %s)" : "الرفع ( حد اقصى. %s ) ",
+    "Files compatibility" : "توافقية الملفات",
+    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "السماح بتقييد أسماء الملفات لضمان إمكانية مزامنة الملفات مع جميع العملاء. بشكل افتراضي، يُسمح بجميع أسماء الملفات الصالحة على POSIX (مثل Linux أو macOS).",
+    "Enforce Windows compatibility" : "فرض التوافق مع وندوز",
+    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "سيؤدي هذا إلى حظر أسماء الملفات غير الصالحة على أنظمة Windows؛ مثل استخدام الأسماء المحجوزة أو الأحرف الخاصة. لكن هذا لن يفرض توافق حساسية الحالة.",
     "Accept" : "قبول",
     "Reject" : "رفض",
     "Incoming ownership transfer from {user}" : "تم تحويل ملكية الملف إليك من قبل {user}",
     "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "هل تريد الموافقة {path}?\n\nملاحظة: عملية موافقة على النقل قد تستغرق إلى 1 ساعة.",
+    "Ownership transfer denied" : "تمّ رفض نقل الملكية",
+    "Your ownership transfer of {path} was denied by {user}." : "تمّ رفض نقلك لمِلكيّتك في {path} من قِبَل المستخدِم {user}.",
     "Ownership transfer failed" : "فشل نقل الملكية",
     "Your ownership transfer of {path} to {user} failed." : "فشلت عمليتك لنقل الـ {path} إلى {user}",
     "The ownership transfer of {path} from {user} failed." : "فشل عملية النقل لـ {path} من قبل {user}",
@@ -168,6 +177,7 @@ OC.L10N.register(
     "Your ownership transfer of {path} to {user} has completed." : "عمليتك لنقل الـ {path} إلى {user} تمت بنجاح.",
     "The ownership transfer of {path} from {user} has completed." : "نقل الملكية لـ {path} من قبل {user} تمت بنجاح.",
     "in %s" : "في %s",
+    "Transferred from %1$s on %2$s" : "تمّ النقل من %1$s في%2$s",
     "File Management" : "إدارة الملفات",
     "Current directory path" : "مسار المجلد الحالي",
     "Reload current directory" : "إعادة تحميل المجلد الحالي",
@@ -176,26 +186,28 @@ OC.L10N.register(
     "Your have used your space quota and cannot upload files anymore" : "لقد استنفذت حصتك التخزينية و لم يعد بإمكانك رفع أي ملفات بعدُ",
     "You don’t have permission to upload or create files here" : "لا تملك الصلاحية لرفع او انشاء ملف هنا ",
     "\"{displayName}\" action executed successfully" : "\"{displayName}\" الأمر نُفّذ بنجاح",
-    "\"{displayName}\" action failed" : "\"{dispalyName}\" الأمر أخفق عند التنفيذ",
+    "\"{displayName}\" action failed" : "\"{displayName}\" الأمر أخفق عند التنفيذ",
     "Toggle selection for file \"{displayName}\"" : "تبديل الاختيار للملف \"{displayName}\"",
     "Toggle selection for folder \"{displayName}\"" : "تبديل الاختيار للمجلد \"{displayName}\"",
+    "File is loading" : "الملف قيد التحميل ...",
+    "Folder is loading" : "المجلد قيد التحميل ...",
     "Rename file" : "إعادة تسمية الملف",
-    "File name" : "اسم الملف",
+    "Filename" : "اسم الملف",
     "Folder name" : "اسم المجلد",
     "This node is unavailable" : "هذه العُقْدَة node غير متوفرة ",
-    "Download file {name}" : " تنزيل الملف {name}",
-    "Invalid file name" : "اسم الملف غير صحيح",
-    "\"{name}\" is not an allowed filetype." : "\"{name}\" ليس نوع ملف مسموحًا به.",
-    "{newName} already exists." : "{newName} موجود بالفعل.",
-    "\"{char}\" is not allowed inside a file name." : "\"{char}\" حرفٌ غير مسموح به في اسم الملف.",
-    "Name cannot be empty" : "لا يمكن أن يكون الاسم فارغاً",
-    "Another entry with the same name already exists" : "إدخال آخر بنفس الاسم موجود بالفعل",
+    "Another entry with the same name already exists." : "توجد سلفاً إدخالية أخرى بنفس هذا الاسم.",
+    "Invalid filename." : "اسم ملف غير صحيح.",
     "Renamed \"{oldName}\" to \"{newName}\"" : "تمت إعادة تسمية \"{oldName}\" إلى \"{newName}\"",
     "Could not rename \"{oldName}\", it does not exist any more" : "تعذر إعادة تسمية \"{oldName}\"، لم يعد موجودًا",
     "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "الاسم \"{newName}\" مُستعمَلٌ سلفاً في المجلّد\"{dir}\". إختَر اسماً آخر رجاءً.",
     "Could not rename \"{oldName}\"" : "تعذرت إعادة تسمية \"{oldName}\"",
+    "Clear filter" : "ازل التصفية",
+    "Type" : "حسب النوع",
+    "Active filters" : "فلاتر نشطة",
+    "Remove filter" : "إزالة الفلتر",
     "Total rows summary" : "ملخص مجموع الأسطر",
     "Toggle selection for all files and folders" : "تبديل الاختيار لكل الملفات و المجلدات",
+    "(selected)" : "(تم اختياره)",
     "\"{displayName}\" failed on some elements " : "\"{displayName}\" فشل في بعض العناصر",
     "\"{displayName}\" batch action executed successfully" : "\"{displayName}\" حزمة الأوامر نُفّذت بنجاح",
     "{count} selected" : "{count} تمّ تحديدها",
@@ -203,13 +215,17 @@ OC.L10N.register(
     "Column headers with buttons are sortable." : "ترويسات الأعمدة ذات الأزرار قابلة للترتيب.",
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "لم يتم عرض هذه القائمة بالكامل لأسباب تتعلق بالأداء. سيتم عرض الملفات تباعاً أثناء التنقل عبر القائمة.",
     "File not found" : "تعذر العثور على الملف",
-    "Storage informations" : "معلومات التخزين",
+    "Storage information" : "معلومات التخزين",
+    "Storage quota" : "حصة التخزين",
     "{usedQuotaByte} used" : "{usedQuotaByte} مستخدمة",
     "{relative}% used" : "{relative}% مستخدمة",
     "Could not refresh storage stats" : "تعذر تحديث حالة التخزين",
     "Your storage is full, files can not be updated or synced anymore!" : "مساحتك التخزينية ممتلئة, لا يمكن تحديث ملفاتك أو مزامنتها بعد الآن !",
     "Create" : "إنشاء",
-    "A file or folder with that name already exists." : "ملف أو مجلد بنفس هذا الاسم موجود سلفاً",
+    "This name is already in use." : "هذا الاسم سبق استعماله.",
+    "Fill template fields" : "قُم بملء حقول القالب",
+    "Submitting fields…" : "إرسال الحقول ...",
+    "Submit" : "إرسال ",
     "Transfer ownership of a file or folder" : "تحويل ملكية ملف أو مجلد",
     "Choose file or folder to transfer" : "اختر ملف او مجلد لنقل الملكية",
     "Change" : "تغير",
@@ -234,10 +250,12 @@ OC.L10N.register(
     "Shared" : "مُشارَكة",
     "Switch to list view" : "التبديل إلى عرض القائمة",
     "Switch to grid view" : "بدِّل إلى المنظور الصندوقي",
+    "Upload was cancelled by user" : "عملية الرفع تمّ إلغاؤها من مُستخدِم",
     "Error during upload: {message}" : "حدث خطأ أثناء الرفع: {message}",
     "Error during upload, status code {status}" : "حدث خطأ أثناء الرفع. رمز الحالة {status}",
     "Unknown error during upload" : "خطأ غير محدد حدث أثناء الرفع",
-    "Open the files app settings" : "إفتح إعدادات تطبيق الملفات",
+    "Filter filenames…" : "فلترة أسماء الملفات ...",
+    "Views" : "مشاهدات",
     "Files settings" : "إعدادات الملفات",
     "File cannot be accessed" : "الملف لم يمكن الوصول إليه",
     "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "إمّا أن الملف غير موجود أو أنك لا تمتلك الصلاحية لعرضه. أُطلُب من المُرسل أن يتشاركه معك.",
@@ -248,6 +266,7 @@ OC.L10N.register(
     "Show hidden files" : "عرض الملفات المخفية",
     "Crop image previews" : "اقتصاص صورة العروض",
     "Enable the grid view" : "تمكين المنظور الصندوقي",
+    "Enable folder tree" : "تمكين شجرة المجلدات",
     "Additional settings" : "الإعدادات المتقدمة",
     "WebDAV" : "WebDAV",
     "WebDAV URL" : "عنوان URL لـ WebDAV",
@@ -263,16 +282,21 @@ OC.L10N.register(
     "Creating file" : "إنشاء ملف",
     "Blank" : "فارغ",
     "Unable to create new file from template" : "تعذر إنشاء الملف الجديد من القالب",
+    "Deletion cancelled" : "تمّ إلغاء الحذف",
     "Delete permanently" : "حذف بشكل دائم",
     "Delete and unshare" : "إحذِف و الغٍ المشاركات ",
     "Leave these shares" : "مغادرة هاتين المشاركتين",
     "Disconnect storages" : "فصل وحدات تخزين",
     "Delete files" : "حذف الملفات",
     "Delete folders" : "حذف مجلدين",
-    "You are about to delete {count} items." : "أنت على وشك حذف {count} عنصر.",
+    "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["أنت على وشك أن تحذف نهائياً  {count} عنصراً","أنت على وشك أن تحذف نهائياً {count} عنصراً","أنت على وشك أن تحذف نهائياً  {count} عنصراً","أنت على وشك أن تحذف نهائياً {count} عناصر","أنت على وشك أن تحذف نهائياً {count} عناصر","أنت على وشك أن تحذف نهائياً {count} عنصراً"],
+    "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["أنت على وشك أن تحذف {count} عنصراً","أنت على وشك أن تحذف {count} عنصراً","أنت على وشك أن تحذف {count} عنصراً","أنت على وشك أن تحذف {count} عناصر","أنت على وشك أن تحذف {count} عناصر","أنت على وشك أن تحذف {count} عنصراً"],
     "Confirm deletion" : "أكِّد على الحذف",
     "Cancel" : "الغاء",
-    "Deletion cancelled" : "تمّ إلغاء الحذف",
+    "Edit file locally" : "تحرير الملف محليّاً",
+    "The file should now open locally. If you don't see this happening, make sure that the desktop client is installed on your system." : "يُفترض أن يفتح الملف الآن محليّاً. إذا لم يكن الأمر كذلك، تأكد من تنصيب تطبيق العميل desktop client على سطح المكتب عندك.",
+    "Retry local edit" : "إعادة محاولة التحرير محليّاً",
+    "Edit online" : "التحرير عبر الإنترنت",
     "Destination is not a folder" : "المَقصَد ليس مُجلّداً",
     "This file/folder is already in that directory" : "هذا الملف/المجلد موجود سلفاً في ذلك المجلد",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "لا يمكنك نقل ملف/مجلد إلى نفسه أو إلى مجلد فرعي منه",
@@ -285,15 +309,29 @@ OC.L10N.register(
     "Choose destination" : "إختَر المَقصِد",
     "Copy to {target}" : "أُنسُخ إلى {target}",
     "Move to {target}" : "أُنقُل إلى {target}",
-    "Cancelled move or copy operation" : ".عملية النسخ أو النقل تمّ إلغاؤها",
     "Move or copy operation failed" : "عملية النسخ أو النقل أخفقت",
+    "Cancelled move or copy of \"{filename}\"." : "تمّ إلغاء عملية حذف أو نقل الملف \"{filename}\".",
+    "Cancelled move or copy operation" : ".عملية النسخ أو النقل تمّ إلغاؤها",
     "Open folder {displayName}" : "إفتح المجلد {displayName}",
     "Open in Files" : "إفتَح في \"الملفات\"",
     "Open details" : "افتح التفاصيل",
+    "Today" : "اليوم",
+    "Last 7 days" : "آخر 7 أيام",
+    "Last 30 days" : "آخر 30 يوماً",
+    "This year ({year})" : "هذا العام ({year})",
+    "Last year ({year})" : "العام الماضي ({year})",
+    "Documents" : "المستندات",
+    "Spreadsheets" : "الجداول الالكترونية",
+    "Presentations" : "العروض",
+    "PDFs" : "ملفات بي دي إف",
+    "Folders" : "المجلدات",
+    "Audio" : "صوت",
+    "Photos and images" : "الصور ",
+    "Videos" : "فيديوهات",
+    "New folder creation cancelled" : "تمّ إلغاء عملية إنشاء مجلد جديد",
     "Created new folder \"{name}\"" : "تمّ إنشاء مجلد جديد باسم \"{name}\"",
-    "Filename" : "اسم الملف",
     "Unable to initialize the templates directory" : "تعذر تهيئة دليل القوالب",
-    "Create new templates folder" : "إنشيْ مجلد جديد للقوالب",
+    "Create templates folder" : "إنشاء مجلد للقوالب",
     "Templates" : "القوالب",
     "New template folder" : "مجلد القوالب الجديد",
     "In folder" : "في المجلد",
@@ -316,11 +354,17 @@ OC.L10N.register(
     "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["ملف واحد 1 و {folderCount} مجلد","ملف واحد 1 و {folderCount} مجلد","ملف واحد 1 و {folderCount} مجلدان","ملف واحد 1 و {folderCount} مجلد","ملف واحد 1 و {folderCount} مجلدات","ملف واحد 1 و {folderCount} مجلدات"],
     "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} ملف و مجلد واحد 1","{fileCount} ملف و مجلد واحد 1","{fileCount} ملفان و مجلد واحد 1","{fileCount} ملف و مجلد واحد 1","{fileCount} ملفات و مجلد واحد 1","{fileCount} ملفات و مجلد واحد 1"],
     "{fileCount} files and {folderCount} folders" : "{fileCount} ملف و {folderCount} مجلد",
+    "Filename must not be empty." : "يجب ألّا يكون اسم الملف فارغاً.",
+    "\"{char}\" is not allowed inside a filename." : "\"{char}\" غير مسموح به في اسم الملف.",
+    "\"{segment}\" is a reserved name and not allowed for filenames." : "\"{segment}\" هو اسم محجوز و لا يجوز استعماله كاسم لملف.",
+    "\"{extension}\" is not an allowed filetype." : "\"{extension}\" غير مسموح به كنوع لملف.",
+    "Filenames must not end with \"{extension}\"." : "أسماء الملفات يجب ألّا تنتهي بـ \"{extension}\".",
     "List of favorites files and folders." : "قائمة الملفات والمجلدات المفضلة.",
     "No favorites yet" : "ليست عندك مفضلات بعد",
     "Files and folders you mark as favorite will show up here" : "الملفات والمجلدات التي حددتها كامفضلة سوف تظهر هنا ",
     "All files" : "كل الملفات",
     "List of your files and folders." : "قائمة بملفاتك و مجلداتك",
+    "All folders" : "كل المجلدات",
     "Personal Files" : "ملفات شخصية",
     "List of your files and folders that are not shared." : "قائمة بالملفات و المجلدات التي لم تتم مشاركتها.",
     "No personal files found" : "لا توجد أي ملفات شخصية",
@@ -336,29 +380,19 @@ OC.L10N.register(
     "New text file.txt" : "ملف نصي جديد fille.txt",
     "Direct link was copied (only works for users who have access to this file/folder)" : "تم نسخ الرابط المباشر (تعمل فقط بالنسبة للمستخدمين الذين يملكون تخويلاً بالوصول إلى هذا الملف أو المجلد)",
     "Copy direct link (only works for users who have access to this file/folder)" : "نسخ الرابط المباشر (يعمل فقط للمستخدمين الذين يمكنهم الوصول الى هذا الملف/المجلد)",
-    "You can only favorite a single file or folder at a time" : "يمكنك فقط تفضيل ملف أو مجلد واحد في المرة الواحدة",
-    "This file has the tag {tag}" : "هذا الملف له واصفة {tag}",
-    "This file has the tags {firstTags} and {lastTag}" : "هذا الملف له واصفات {firstTags} و {lastTag}",
     "\"remote user\"" : "\"مستخدم عن بعد\"",
-    "Select the row for {displayName}" : "إختر السطر في {displayName}",
-    "Open folder {name}" : "إفتح المجلد {name}",
-    "Unselect all" : "إلغاء الاختيار للكل",
-    "ascending" : "تصاعدياً",
-    "descending" : "تنازلياً",
-    "Sort list by {column} ({direction})" : "ترتيب القائمة بحسب {column} ({direction})",
-    "This list is not fully rendered for performances reasons. The files will be rendered as you navigate through the list." : "لم يمكن عرض هذه القائمة بالكامل بسبب إشكالية في الأداء. سيتم عرض الملفات عندما تمر عليها في القائمة",
-    "Search for an account" : "البحث عن حساب",
-    "Choose" : "إختَر",
-    "No files or folders have been deleted yet" : "لم يتم حذف أي ملفات أو مجلدات بعدُ",
+    "{newName} already exists." : "{newName} موجود بالفعل.",
+    "\"{segment}\" is not allowed inside a filename." : "\"{segment}\" غير مقبولة في اسم الملف.",
+    "\"{segment}\" is a forbidden file or folder name." : "\"{segment}\" محظور استعماله كاسم لملف أو مجلد.",
+    "\"{segment}\" is not an allowed filetype." : "\"{segment}\" غير مقبول كنوع لملف.",
+    "Filenames must not end with \"{segment}\"." : "أسماء الملفات يجب ألّا تنتهي بـ \"{segment}\".",
+    "Name cannot be empty" : "لا يمكن أن يكون الاسم فارغاً",
+    "Another entry with the same name already exists" : "إدخال آخر بنفس الاسم موجود بالفعل",
+    "Storage informations" : "معلومات التخزين",
+    "Open the files app settings" : "إفتح إعدادات تطبيق الملفات",
     "You might not have have permissions to view it, ask the sender to share it" : "يمكن ألاّ تكون لديك صلاحية لعرضه، أطلب من المُرسل إن يشاركه معك",
-    "Set up templates folder" : "إعداد مجلد القوالب",
-    "Toggle %1$s sublist" : "تبديل %1$s قائمة فرعية",
-    "Toggle grid view" : "تفعيل/تعطيل القائمة",
-    "Shares" : "التي قمتَ بمشاركتها",
-    "Shared with others" : "شاركته مع الاخرين",
-    "Shared with you" : "تمت مشاركته معك",
-    "Deleted shares" : "تم حذف المشاركات",
-    "Pending shares" : "انتظار المشاركات",
-    "The files is locked" : "الملفات مقفله"
+    "The files is locked" : "الملفات مقفله",
+    "Create new templates folder" : "إنشيْ مجلد جديد للقوالب",
+    "Toggle %1$s sublist" : "تبديل %1$s قائمة فرعية"
 },
 "nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
