@@ -137,8 +137,8 @@ OC.L10N.register(
     "You changed an encrypted file in {file}" : "Zmenili ste šifrovaný súbor {file}",
     "{user} changed {file}" : "{user} zmenil {file}",
     "{user} changed an encrypted file in {file}" : "{user} zmenil šifrovaný súbor {file}",
-    "You deleted {file}" : "Zmazali ste {file}",
-    "You deleted an encrypted file in {file}" : "Zmazali ste šifrovaný súbor {file}",
+    "You deleted {file}" : "Odstránili ste {file}",
+    "You deleted an encrypted file in {file}" : "Odstránili ste šifrovaný súbor {file}",
     "{user} deleted {file}" : "{user} zmazal {file}",
     "{user} deleted an encrypted file in {file}" : "{user} zmazal šifrovaný súbor {file}",
     "You restored {file}" : "Obnovili ste {file}",
@@ -156,11 +156,18 @@ OC.L10N.register(
     "A file has been added to or removed from your <strong>favorites</strong>" : "Súbor bol pridaný alebo odstránený z vašich <strong>obľúbených</strong>",
     "A file or folder has been <strong>changed</strong>" : "Súbor alebo priečinok bol <strong>zmenený</strong>",
     "A favorite file or folder has been <strong>changed</strong>" : "Obľúbený súbor alebo priečinok bol <strong>zmenený</strong>",
+    "Failed to authorize" : "Autorizácia zlyhala",
     "Upload (max. %s)" : "Nahrať (max. %s)",
+    "Files compatibility" : "Kompatibilita súborov",
+    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Povoliť obmedzenie názvov súborov, aby sa zabezpečila synchronizácia súborov so všetkými klientmi. V predvolenom nastavení sú povolené všetky názvy súborov platné pre POSIX (napr. Linux alebo macOS).",
+    "Enforce Windows compatibility" : "Vynútiť kompatibilitu s Windows",
+    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Tým sa zablokujú názvy súborov, ktoré nie sú platné v systémoch Windows, ako napríklad používanie vyhradených názvov alebo špeciálnych znakov. To však nevynúti kompatibilitu rozlišovania malých a veľkých písmen.",
     "Accept" : "Prijať",
     "Reject" : "Odmietnuť",
     "Incoming ownership transfer from {user}" : "Prichádzajúci prevod vlastníctva od {user}",
     "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Chcete prijať {path}?\n\nPozn.: Proces pre prijatie môže trvať až hodinu.",
+    "Ownership transfer denied" : "Prevod vlastníctva bol odmietnutý",
+    "Your ownership transfer of {path} was denied by {user}." : "{user} odmietol prevod vlastníctva {path}.",
     "Ownership transfer failed" : "Prevod vlastníctva zlyhal",
     "Your ownership transfer of {path} to {user} failed." : "Prevod vlastníctva {path} od vás na {user} zlyhal.",
     "The ownership transfer of {path} from {user} failed." : "Prevod vlastníctva {path} od {user} zlyhal.",
@@ -168,6 +175,7 @@ OC.L10N.register(
     "Your ownership transfer of {path} to {user} has completed." : "Prevod vami vlastnenej položky {path} na {user} bol dokončený.",
     "The ownership transfer of {path} from {user} has completed." : "Prevod vlastníctva položky {path} od {user} bol dokončený.",
     "in %s" : "v %s",
+    "Transferred from %1$s on %2$s" : "Prevedené z %1$s na %2$s",
     "File Management" : "Správa súborov",
     "Current directory path" : "Aktuálna cesta k adresáru",
     "Reload current directory" : "Znova načítať súčasný adresár",
@@ -180,19 +188,19 @@ OC.L10N.register(
     "Toggle selection for file \"{displayName}\"" : "Prepnúť výber pre súbor \"{displayName}\"",
     "Toggle selection for folder \"{displayName}\"" : "Prepnúť výber pre adresár \"{displayName}\"",
     "Rename file" : "Premenovať súbor",
-    "File name" : "Názov súboru",
+    "Filename" : "Názov súboru",
     "Folder name" : "Názov priečinka",
     "This node is unavailable" : "Uzol nie je k dispozícií",
-    "Download file {name}" : "Stiahnuť súbor {name}",
-    "\"{name}\" is not an allowed filetype." : "\"{name}\" nie je povolený typ súboru",
-    "{newName} already exists." : "{newName} už existuje.",
-    "\"{char}\" is not allowed inside a file name." : "Znak \"{char}\" nie je povolený v názve súboru.",
-    "Name cannot be empty" : "Názov nemôže byť prázdny",
-    "Another entry with the same name already exists" : "Názov už existuje",
+    "Another entry with the same name already exists." : "Iná položka s rovnakým menom už existuje.",
+    "Invalid filename." : "Chybný názov súboru.",
     "Renamed \"{oldName}\" to \"{newName}\"" : "Premenované z \"{oldName}\" na \"{newName}\"",
     "Could not rename \"{oldName}\", it does not exist any more" : "Nebolo možné premenovať  \"{oldName}\". Položka už neexistuje.",
     "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Názov \"{newName}\" sa už používa v priečinku \"{dir}\". Vyberte prosím iný názov.",
     "Could not rename \"{oldName}\"" : "Nebolo možné premenovať \"{oldName}\"",
+    "Clear filter" : "Vyčistiť filter",
+    "Type" : "Typ",
+    "Active filters" : "Aktívne filtre",
+    "Remove filter" : "Odstrániť filter",
     "Total rows summary" : "Súčet všetkých riadkov",
     "Toggle selection for all files and folders" : "Prepnúť výber pre všetky súbory a adresáre",
     "\"{displayName}\" failed on some elements " : "\"{displayName}\" zlyhalo na niektorých prvkoch.",
@@ -202,13 +210,17 @@ OC.L10N.register(
     "Column headers with buttons are sortable." : "Stĺpce hlavičiek s tlačidlami sú triediteľné.",
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Tento zoznam nie je úplne vykreslený z dôvodov výkonu. Súbory budú vykreslené, keď budete prechádzať zoznamom.",
     "File not found" : "Súbor nenájdený",
-    "Storage informations" : "Úložiskové informácie",
+    "Storage information" : "Informácie o úložisku",
+    "Storage quota" : "Kvóta pre úložisko",
     "{usedQuotaByte} used" : "{usedQuotaByte} použitých",
     "{relative}% used" : "{relative}% použitých",
     "Could not refresh storage stats" : "Nebolo možné obnoviť úložiskové štatistiky",
     "Your storage is full, files can not be updated or synced anymore!" : "Vaše úložisko je plné. Súbory nemožno aktualizovať ani synchronizovať!",
     "Create" : "Vytvoriť",
-    "A file or folder with that name already exists." : "Súbor alebo priečinok s týmto názvom už existuje.",
+    "This name is already in use." : "Toto meno je už používané.",
+    "Fill template fields" : "Vyplňte položky šablóny",
+    "Submitting fields…" : "Položky sa odosielajú ...",
+    "Submit" : "Odoslať",
     "Transfer ownership of a file or folder" : "Prevod vlastníctva súboru alebo priečinka",
     "Choose file or folder to transfer" : "Vyberte súbor alebo priečinok na prevod",
     "Change" : "Zmeniť",
@@ -233,10 +245,12 @@ OC.L10N.register(
     "Shared" : "Sprístupnené",
     "Switch to list view" : "Prepnúť na zobrazenie v zozname",
     "Switch to grid view" : "Prepnúť na zobrazenie v mriežke",
+    "Upload was cancelled by user" : "Nahrávanie bolo zrušené užívateľom",
     "Error during upload: {message}" : "Chyba počas nahrávania: {message}",
     "Error during upload, status code {status}" : "Chyba počas nahrávania, chybový kód {status}",
     "Unknown error during upload" : "Neznáma chyba počas nahrávania",
-    "Open the files app settings" : "Otvoriť nastavenia súborovej aplikácie",
+    "Filter filenames…" : "Filtrovať názvy súborov...",
+    "Views" : "Zobrazenia",
     "Files settings" : "Nastavenia súborov",
     "File cannot be accessed" : "Súbor nie je možné sprístupniť",
     "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Súbor sa nenašiel alebo nemáte oprávnenie na jeho zobrazenie. Požiadajte odosielateľa, aby ho sprístupnil.",
@@ -247,6 +261,7 @@ OC.L10N.register(
     "Show hidden files" : "Zobraziť skryté súbory",
     "Crop image previews" : "Orezať náhľady obrázkov",
     "Enable the grid view" : "Povoliť zobrazenie v mriežke",
+    "Enable folder tree" : "Povoliť adresárový strom",
     "Additional settings" : "Ďalšie nastavenia",
     "WebDAV" : "WebDAV",
     "WebDAV URL" : "WebDAV URL",
@@ -262,16 +277,21 @@ OC.L10N.register(
     "Creating file" : "Vytvára sa súbor",
     "Blank" : "Prázdne",
     "Unable to create new file from template" : "Nemôžem vytvoriť nový súbor zo šablóny",
+    "Deletion cancelled" : "Zmazanie zrušené",
     "Delete permanently" : "Zmazať  natrvalo",
     "Delete and unshare" : "Vymazať a zrušiť zdieľanie",
     "Leave these shares" : "Opustiť tieto zdieľania.",
     "Disconnect storages" : "Odpojiť úložiská",
     "Delete files" : "Zmazať súbory",
     "Delete folders" : "Zmazať priečinky",
-    "You are about to delete {count} items." : "Chystáte sa vymazať {count} položiek.",
+    "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["Chystáte sa permanentne vymazať {count} položku","Chystáte sa permanentne vymazať {count} položky","Chystáte sa permanentne vymazať {count} položiek","Chystáte sa permanentne vymazať {count} položiek"],
+    "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["Chystáte sa vymazať {count} položku","Chystáte sa vymazať {count} položky","Chystáte sa vymazať {count} položiek","Chystáte sa vymazať {count} položiek"],
     "Confirm deletion" : "Potvrdiť vymazanie",
     "Cancel" : "Zrušiť",
-    "Deletion cancelled" : "Zmazanie zrušené",
+    "Edit file locally" : "Editovať súbor lokálne",
+    "The file should now open locally. If you don't see this happening, make sure that the desktop client is installed on your system." : "Súbor by sa mal teraz otvoriť lokálne. Ak sa to nestane, uistite sa, že je vo vašom systéme nainštalovaný desktopový klient.",
+    "Retry local edit" : "Opakovať úpravu lokálne",
+    "Edit online" : "Upraviť online",
     "Destination is not a folder" : "Cieľ nie je priečinok",
     "This file/folder is already in that directory" : "Tento súbor/priečinok sa už v danom adresári nachádza",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "Nemôžete presunúť súbor/priečinok do seba alebo do jeho podpriečinka.",
@@ -284,15 +304,27 @@ OC.L10N.register(
     "Choose destination" : "Vyberte cieľ",
     "Copy to {target}" : "Kopírovať do {target}",
     "Move to {target}" : "Presunúť do {target}",
-    "Cancelled move or copy operation" : "Zrušená operácia kopírovania alebo presunu",
     "Move or copy operation failed" : "Operácia presunu alebo kopírovania zlyhala",
+    "Cancelled move or copy of \"{filename}\"." : "Zrušené kopírovanie alebo presun \"{filename}\".",
+    "Cancelled move or copy operation" : "Zrušená operácia kopírovania alebo presunu",
     "Open folder {displayName}" : "Otvoriť priečinok {displayName}",
     "Open in Files" : "Otvoriť v súboroch",
     "Open details" : "Otvoriť detaily",
+    "Today" : "Dnes",
+    "Last 7 days" : "Posledných 7 dní",
+    "Last 30 days" : "Posledných 30 dní",
+    "This year ({year})" : "Tento rok ({year})",
+    "Last year ({year})" : "Minulý rok ({year})",
+    "Documents" : "Dokumenty",
+    "Spreadsheets" : "Tabuľky",
+    "Presentations" : "Prezentácie",
+    "PDFs" : "PDFká",
+    "Folders" : "Priečinky",
+    "Audio" : "Zvuk",
+    "Videos" : "Videá",
     "Created new folder \"{name}\"" : "Vytvorený nový priečinok \"{name}\"",
-    "Filename" : "Názov súboru",
     "Unable to initialize the templates directory" : "Nemôžem inicializovať priečinok so šablónami",
-    "Create new templates folder" : "Vytvoriť nový vzorový priečinok",
+    "Create templates folder" : "Vytvoriť adresár pre šablóny",
     "Templates" : "Šablóny",
     "New template folder" : "Nový adresár šablóny",
     "In folder" : "V adresári",
@@ -315,11 +347,17 @@ OC.L10N.register(
     "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 súbor a {folderCount} priečinok","1 súbor a {folderCount} priečinky","1 súbor a {folderCount} priečinky","1 súbor a {folderCount} priečinky"],
     "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} súbor a 1 priečinok","{fileCount} súborov a 1 priečinok","{fileCount} súborov a 1 priečinok","{fileCount} súborov a 1 priečinok"],
     "{fileCount} files and {folderCount} folders" : "{fileCount} súborov a {folderCount} priečinkov",
+    "Filename must not be empty." : "Názov súboru nesmie byť prázdny.",
+    "\"{char}\" is not allowed inside a filename." : "Znak \"{char}\" nie je povolený v názve súboru.",
+    "\"{segment}\" is a reserved name and not allowed for filenames." : "\"{segment}\" je rezervované slovo a nie je možné ho použiť v názvoch súborov.",
+    "\"{extension}\" is not an allowed filetype." : "\"{extension}\" nie je povolená prípona súboru.",
+    "Filenames must not end with \"{extension}\"." : "Názvy súborov nesmú končiť s \"{extension}\"",
     "List of favorites files and folders." : "Zoznam obľúbených súborov a priečinkov.",
     "No favorites yet" : "Zatiaľ žiadne obľúbené",
     "Files and folders you mark as favorite will show up here" : "Súbory a priečinky označené ako obľúbené budú zobrazené tu",
     "All files" : "Všetky súbory",
     "List of your files and folders." : "Zoznam vašich súborov a priečinkov.",
+    "All folders" : "Všetky adresáre",
     "Personal Files" : "Osobné Súbory",
     "List of your files and folders that are not shared." : "Zoznam vašich súborov a priečinkov, ktoré nie sú zdieľané.",
     "No personal files found" : "Žiadne osobné súbory nenájdené",
@@ -335,29 +373,15 @@ OC.L10N.register(
     "New text file.txt" : "Nový text file.txt",
     "Direct link was copied (only works for users who have access to this file/folder)" : "Priamy odkaz bol skopirovaný (funguje iba pre používateľov, ktorí majú prístup k danému súboru/adresáru)",
     "Copy direct link (only works for users who have access to this file/folder)" : "Kopírovať priamy odkaz (funguje iba pre používateľov, ktorí majú prístup k tomuto súboru/priečinku)",
-    "You can only favorite a single file or folder at a time" : "Do obľúbených je možné zaradovať súbory a zložky len jednotlivo",
-    "This file has the tag {tag}" : "Tento súbor má štítok {tag}",
-    "This file has the tags {firstTags} and {lastTag}" : "Tento súbor má štítky {firstTags} a {lastTag}",
     "\"remote user\"" : "\"vzdialený používateľ\"",
-    "Select the row for {displayName}" : "Vybrať riadok pre {displayName}",
-    "Open folder {name}" : "Otvoriť súbor {name}",
-    "Unselect all" : "Zrušiť výber",
-    "ascending" : "vzostupne",
-    "descending" : "zostupne",
-    "Sort list by {column} ({direction})" : "Zoradiť zoznam podľa {column} ({direction})",
-    "This list is not fully rendered for performances reasons. The files will be rendered as you navigate through the list." : "Tento zoznam nie je úplne vykreslený z dôvodov výkonu. Súbory budú vykreslené, keď budete prechádzat zoznamom.",
-    "Search for an account" : "Vyhľadať účet",
-    "Choose" : "Vybrať",
-    "No files or folders have been deleted yet" : "Žiadne súbory alebo priečinky neboli ešte vymazané",
+    "{newName} already exists." : "{newName} už existuje.",
+    "Name cannot be empty" : "Názov nemôže byť prázdny",
+    "Another entry with the same name already exists" : "Názov už existuje",
+    "Storage informations" : "Úložiskové informácie",
+    "Open the files app settings" : "Otvoriť nastavenia súborovej aplikácie",
     "You might not have have permissions to view it, ask the sender to share it" : "Pravdopodobne nemáte prístup, požiadajte oň odosielateľa ",
-    "Set up templates folder" : "Nastaviť priečinok pre šablóny",
-    "Toggle %1$s sublist" : "Prepnúť %1$s podzoznam",
-    "Toggle grid view" : "Prepnúť zobrazenie mriežky",
-    "Shares" : "Zdieľania",
-    "Shared with others" : "Sprístupnené ostatným",
-    "Shared with you" : "Vám sprístupnené",
-    "Deleted shares" : "Odstránené sprístupnenia",
-    "Pending shares" : "Čakajúce prístupy",
-    "The files is locked" : "Súbory sú uzamknuté"
+    "The files is locked" : "Súbory sú uzamknuté",
+    "Create new templates folder" : "Vytvoriť nový vzorový priečinok",
+    "Toggle %1$s sublist" : "Prepnúť %1$s podzoznam"
 },
 "nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
