@@ -101,6 +101,7 @@ OC.L10N.register(
     "Administration" : "Административни",
     "Users" : "Потребители",
     "Additional settings" : "Допълнителни настройки",
+    "Artificial Intelligence" : "Изкуствен интелект",
     "Administration privileges" : "Административни привилегии",
     "Groupware" : "Групов софтуер",
     "Overview" : "Преглед",
@@ -117,7 +118,6 @@ OC.L10N.register(
     "Verifying" : "Потвърждаване",
     "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Вероятно вашите данни и файлове са достъпни от интернет. .htaccess файлът не функционира. Силно се препоръчва да настроите уеб сървъра по такъв начин, че директорията за данни да не бъде достъпна или я преместете извън началната директория на уеб сървъра.",
     "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "В базата данни липсват някои изборни колони. Поради факта, че добавянето на колони в големи таблици може да отнеме известно време, те не се добавят автоматично, когато могат да бъдат по избор. Чрез стартиране на \"occ db: add-missing-колони\" тези липсващи колони могат да бъдат добавени ръчно, докато екземплярът продължава да работи. След като колоните бъдат добавени, някои функции могат да подобрят отзивчивостта или използваемостта.",
-    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "Някои индекси липсват в базата данни. Не са добавени защото процеса може да отнеме доста време. Можете да стартирате процеса ръчно като изпълните командата \"occ db:add-missing-indices\". След добавянето на индексите заявките към изброените таблици ще минават много по-бързо.",
     "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "В базата данни липсват някои първични ключове. Поради факта, че добавянето на първични ключове на големи маси може да отнеме известно време, те не бяха добавени автоматично. Чрез стартиране на \"occ db: add-missing-primary-keys\" тези липсващи първични ключове могат да бъдат добавени ръчно, докато екземплярът продължава да работи.",
     "This server has no working internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the internet to enjoy all features." : "Сървърът няма работеща интернет връзка: Множество крайни точки не могат да бъдат достигнати. Това означава, че някои от функциите като монтиране на външно хранилище, известия за актуализации или инсталиране на приложения на трети страни няма да работят. Достъпът до файлове от разстояние и изпращането на имейли с известие, също може да не работят. Установете връзка от този сървър с Интернет, за да се насладите на всички функции.",
     "Disabled" : "Изключено",
@@ -128,9 +128,6 @@ OC.L10N.register(
     "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "Изглежда, че PHP не е настроен правилно за заявки за променливи на системната среда. Тестът с getenv (\"ПЪТ\") връща само празен отговор.",
     "The PHP OPcache module is not loaded. For better performance it is recommended to load it into your PHP installation." : "PHP OPcache модулът не е зареден. За по-добра производителност се препоръчва да го заредите във вашата PHP инсталация.",
     "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : " Активирана е конфигурацията само за четене. Това предотвратява настройването на някои конфигурации чрез уеб интерфейса. Освен това файлът трябва ръчно да се направи записваем за всяка актуализация.",
-    "MariaDB version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MariaDB 10.2 or higher." : "Използва се версия на MariaDB „%s “. Nextcloud 21 и по-новите версии вече няма да поддържат тази версия и се изисква MariaDB 10.2 или по-нова версия.",
-    "MySQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MySQL 8.0 or MariaDB 10.2 or higher." : "Използва се версия на MySQL „ %s“. Nextcloud 21 и по-новите версии вече няма да поддържат тази версия и се изискват MySQL 8.0 или MariaDB 10.2, или по-нова версия.",
-    "PostgreSQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require PostgreSQL 9.6 or higher." : "Използва се PostgreSQL версия „%s “. Nextcloud 21 и по-новите версии вече няма да поддържат тази версия и се изисква PostgreSQL 9.6 или по-нова версия.",
     "Architecture" : "Архитектура",
     "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Вашата база данни не се изпълнява с ниво на изолация на транзакциите „АНГАЖИРАНО ЧЕТЕНЕ . Това може да създаде проблеми при паралелно изпълнение на множество действия.",
     "Profile information" : "Информация за профила",
@@ -151,7 +148,6 @@ OC.L10N.register(
     "Enforce expiration date" : "Изисквай срок на валидност",
     "Set default expiration date for shares to other servers" : "Задайте дата на изтичане по подразбиране за споделяния към други сървъри",
     "If autocompletion \"same group\" and \"phone number integration\" are enabled a match in either is enough to show the user." : "Ако автоматичното довършване „същата група“ и „интегриране на телефонен номер“ са активирани, съвпадението в едното е достатъчно, за да се покаже на потребителя.",
-    "Allow username autocompletion to users based on phone number integration" : "Разрешаване на автоматично довършване на име на потребител на потребители въз основа на интегриране на телефонен номер",
     "Allow autocompletion when entering the full name or email address (ignoring missing phonebook match and being in the same group)" : "Разрешаване на автоматично довършване при въвеждане на пълното име или имейл адрес (като игнорирате липсващото съвпадение в телефонния указател и сте в същата група)",
     "Show disclaimer text on the public link upload page (only shown when the file list is hidden)" : "Показване на текст за отказ от отговорност на страницата за качване на публична връзка (показва се само когато списъкът с файлове е скрит)",
     "This text will be shown on the public link upload page when the file list is hidden." : "Този текст ще се показва на страницата за качване на публична връзка, когато списъкът с файлове е скрит.",
@@ -326,19 +322,17 @@ OC.L10N.register(
     "Common languages" : "Познати езици",
     "Other languages" : "Други езици",
     "Password change is disabled because the master key is disabled" : "Промяната на паролата е деактивирана, защото главният ключ е деактивиран",
-    "New user" : "Нов потребител",
     "Display name" : "Вписване като",
     "Email" : "Имейл",
     "Quota" : "Квота",
     "Language" : "Език",
     "Total rows summary" : "Обобщение на общия брой редове",
     "Avatar" : "Аватар",
-    "Username" : "Потребител",
+    "Account name" : "Име на профил",
     "Group admin for" : "Групов администратор за",
-    "User backend" : "Потребителски сървър",
     "Storage location" : "Дисково пространство",
     "Last login" : "Последно вписване",
-    "Add user to group" : "Добавяне на потребител към група",
+    "Account actions" : "Действия на профил",
     "{size} used" : "{size} използвани",
     "Delete account" : "Изтриване на профила",
     "Resend welcome email" : "Повторно изпращане на имейл за добре дошъл ",
@@ -409,6 +403,7 @@ OC.L10N.register(
     "Error while updating device token name" : "Грешка при актуализиране на името на токена на устройството",
     "Error while updating device token scope" : "Грешка при актуализиране на обхвата на токена на устройството",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Имаше твърде много заявки от вашата мрежа. Опитайте отново по-късно или се свържете с вашия администратор, ако това е грешка.",
+    "Error" : "Грешка",
     "Forum" : "Форум",
     "Legal notice" : "Правна информация",
     "Privacy policy" : "Политика за поверителност",
@@ -447,93 +442,48 @@ OC.L10N.register(
     "No user supplied" : "Липсва потребител",
     "Please provide an admin recovery password; otherwise, all user data will be lost." : "Моля, да предоставите администраторска парола за възстановяване; в противен случай всички потребителски данни ще бъдат загубени.",
     "Backend does not support password change, but the user's encryption key was updated." : "Сървърът не поддържа промяна на паролата, но ключът за криптиране на потребителя беше актуализиран.",
-    "installing and updating apps via the App Store or Federated Cloud Sharing" : "инсталиране и актуализиране на приложения чрез App Store или Federated Cloud Sharing/Федерирано споделяне в облак/",
-    "Federated Cloud Sharing" : "Федерирано споделяне в облак",
-    "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "cURL използва остаряла %1$s  версия на (%2$s). Моля, актуализирайте операционната си система или функции като %3$s, няма да работят надеждно.",
-    "Could not determine if TLS version of cURL is outdated or not because an error happened during the HTTPS request against https://nextcloud.com. Please check the Nextcloud log file for more details." : "Не можа да се определи дали TLS версията на cURL е остаряла или не, защото възникна грешка по време на HTTPS заявката срещу https://nextcloud.com. Моля, проверете регистрационния файл /журнал/ на  Nextcloud за повече подробности.",
-    "OPcache is disabled. For better performance, it is recommended to apply <code>opcache.enable=1</code> to your PHP configuration." : "OPcache е деактивиран. За по-добра производителност се препоръчва да се приложи <code>opcache.enable=1</code> към вашата PHP конфигурация.",
-    "OPcache is configured to remove code comments. With OPcache enabled, <code>opcache.save_comments=1</code> must be set for Nextcloud to function." : "OPcache е конфигуриран за премахване на кодови коментари. С активиран OPcache, <code>opcache.save_comments=1</code> трябва да бъде настроен за Nextcloud, за да функционира.",
-    "Nextcloud is not allowed to use the OPcache API. With OPcache enabled, it is highly recommended to include all Nextcloud directories with <code>opcache.restrict_api</code> or unset this setting to disable OPcache API restrictions, to prevent errors during Nextcloud core or app upgrades." : "Nextcloud няма право да използва OPcache API. При активиран OPcache е силно препоръчително да включите всички директории Nextcloud с <code>opcache.restrict_api</code> или деактивирайте тази настройка, за да деактивирате ограниченията на OPcache API, за да предотвратите грешки по време на надстройки на ядрото или приложението на Nextcloud.",
-    "Nextcloud is not allowed to use the OPcache API. It is highly recommended to include all Nextcloud directories with <code>opcache.restrict_api</code> or unset this setting to disable OPcache API restrictions, to prevent errors during Nextcloud core or app upgrades." : "Nextcloud няма право да използва OPcache API. Силно препоръчително е да включите всички директории Nextcloud с <code>opcache.restrict_api</code> или деактивирайте тази настройка, за да деактивирате ограниченията на OPcache API, за да предотвратите грешки по време на надстройки на ядрото или приложението на Nextcloud.",
-    "The shared memory based OPcache is disabled. For better performance, it is recommended to apply <code>opcache.file_cache_only=0</code> to your PHP configuration and use the file cache as second level cache only." : "Базираният на споделена памет OPcache е деактивиран. За по-добра производителност се препоръчва да приложите <code>opcache.file_cache_only=0</code> към конфигурацията на PHP и да използвате файловия кеш само като кеш от второ ниво.",
-    "The maximum number of OPcache keys is nearly exceeded. To assure that all scripts can be kept in the cache, it is recommended to apply <code>opcache.max_accelerated_files</code> to your PHP configuration with a value higher than <code>%s</code>." : "Максималният брой OPcache ключове почти е надвишен. За да се гарантира, че всички скриптове могат да се задържат в кеш, се препоръчва да се приложи <code>opcache.max_accelerated_files</code> към вашата PHP конфигурация със стойност, по-висока от <code>%s</code>.",
-    "The OPcache buffer is nearly full. To assure that all scripts can be hold in cache, it is recommended to apply <code>opcache.memory_consumption</code> to your PHP configuration with a value higher than <code>%s</code>." : "Буферът на OPcache е почти пълен. За да се гарантира, че всички скриптове могат да се задържат в кеш, се препоръчва да се приложи <code>opcache.memory_consumption</code> към вашата PHP конфигурация със стойност, по-висока от <code>%s</code>.",
-    "The OPcache interned strings buffer is nearly full. To assure that repeating strings can be effectively cached, it is recommended to apply <code>opcache.interned_strings_buffer</code> to your PHP configuration with a value higher than <code>%s</code>." : "Буферът за интернирани низове в OPcache е почти пълен. За да се гарантира, че повтарящите се низове могат да бъдат ефективно кеширани, се препоръчва да се приложи <code>opcache.interned_strings_buffer</code> към вашата PHP конфигурация със стойност, по-висока от<code>%s</code>.",
     "You need to set your user email before being able to send test emails. Go to %s for that." : "Трябва да зададете свои потребителски имейл, преди да можете да изпращате тестови имейли. За това отидете на %s.",
     "Invalid user" : "Невалиден потребител",
     "Your username is: %s" : "Потребителско име: %s",
     "Logged in user must be a subadmin" : "Влезлият потребител трябва да е подадминистратор",
     "A background job is pending that checks for user imported SSL certificates. Please check back later." : "Предстои фонова работа, която проверява за импортирани от потребителя SSL сертификати. Моля, проверете отново по-късно.",
     "There are some user imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below." : "Има някои импортирани от потребителя SSL сертификати, които вече не се използват с Nextcloud 21. Те ​​могат да бъдат импортирани в командния ред, чрез командата \"occ security:certificates:import\". Техните пътища в директорията с данни са показани по-долу.",
-    "Invalid UUIDs of LDAP users or groups have been found. Please review your \"Override UUID detection\" settings in the Expert part of the LDAP configuration and use \"occ ldap:update-uuid\" to update them." : "Открит е невалиден UUID на потребители или групи на LDAP. Моля, прегледайте настройките си за \"Override UUID detection\"/ откриване на отмяна на UUID/, в експертната част на LDAP конфигурацията и използвайте \"occ ldap:update-uuid\", за да ги актуализирате.",
+    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "Някои индекси липсват в базата данни. Не са добавени защото процеса може да отнеме доста време. Можете да стартирате процеса ръчно като изпълните командата \"occ db:add-missing-indices\". След добавянето на индексите заявките към изброените таблици ще минават много по-бързо.",
+    "MariaDB version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MariaDB 10.2 or higher." : "Използва се версия на MariaDB „%s “. Nextcloud 21 и по-новите версии вече няма да поддържат тази версия и се изисква MariaDB 10.2 или по-нова версия.",
+    "MySQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MySQL 8.0 or MariaDB 10.2 or higher." : "Използва се версия на MySQL „ %s“. Nextcloud 21 и по-новите версии вече няма да поддържат тази версия и се изискват MySQL 8.0 или MariaDB 10.2, или по-нова версия.",
+    "PostgreSQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require PostgreSQL 9.6 or higher." : "Използва се PostgreSQL версия „%s “. Nextcloud 21 и по-новите версии вече няма да поддържат тази версия и се изисква PostgreSQL 9.6 или по-нова версия.",
+    "Exclude groups from sharing" : "Забрани групи да споделят",
+    "These groups will still be able to receive shares, but not to initiate them." : "Тези групи ще могат да получават споделения, но няма да могат самите те да споделят.",
     "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "Двустепенното удостоверяване може да бъде наложено за всички потребители и специфични групи. Ако нямат конфигуриран двустепенен доставчик, те няма да могат да влязат в системата.",
     "When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "Когато групите са избрани/изключени, те използват следната логика, за да определят дали даден потребител има наложена 2FA: Ако не са избрани групи, 2FA се активира за всички, с изключение на членовете на изключените групи. Ако са избрани групи, 2FA се активира за всички техни членове. Ако потребител е едновременно в избрана и изключена група, избраното има предимство и 2FA се прилага.",
-    "Enable all" : "Активирай всички",
-    "Internet Explorer" : "Internet Explorer",
-    "Edge" : "Edge",
-    "Firefox" : "Firefox",
-    "Google Chrome" : "Google Chrome",
-    "Safari" : "Safari",
-    "iPhone" : "iPhone",
-    "iPad" : "iPad",
-    "Sync client - {os}" : "Клиент за синхронизиране - {os}",
-    "Error while deleting the token" : "Грешка при изтриването на токен",
-    "Use the credentials below to configure your app or device." : "Ползвайте данните по-долу за да настроите вашето приложение или устройство.",
-    "For security reasons this password will only be shown once." : "Тази парола ще бъде показана само веднъж.",
-    "Copied!" : "Копирано!",
-    "Copy" : "Копиране",
+    "{license}-licensed" : "{license}-лицензиран",
+    "Username" : "Потребител",
     "Execute one task with each page loaded. Use case: Single user instance." : "Изпълняване на една задача с всяка заредена страница. Случай на употреба: Екземпляр за един потребител.",
     "cron.php is registered at a webcron service to call cron.php every 5 minutes over HTTP. Use case: Very small instance (1–5 users depending on the usage)." : "cron.php е регистриран в услуга на webcron за извикване на cron.php на всеки 5 минути през HTTP. Случай на употреба: Много малък екземпляр (1–5 потребители в зависимост от употребата).",
-    "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "За да стартирате това, имате нужда от разширението PHP POSIX. Вижте {linkstart}документацията на PHP{linkend} за повече подробности.",
-    "Use system cron service to call the cron.php file every 5 minutes. Recommended for all instances." : "Използвайте системна услуга cron, за да извиквате файла cron.php на всеки 5 минути. Препоръчва се за всички екземпляри.",
     "The cron.php needs to be executed by the system user \"{user}\"." : "Cron.php трябва да се изпълни от системният потребител \"{user}\".",
     "Enable or disable profile by default for new users." : "Активиране или деактивиране на профила по подразбиране за нови потребители.",
-    "You are about to remove the group {group}. The users will NOT be deleted." : "На път сте да премахнете групата {group}. Потребителите НЯМА да бъдат изтрити.",
-    "Please confirm the group removal " : "Моля, потвърдете премахването на групата",
-    "Your profile information" : "Информация за вашия профил",
-    "Your email address" : "Вашият имейл адрес",
     "Additional emails" : "Допълнителни имейли",
     "Enable Profile" : "Активиране на профил",
-    "Your Twitter handle" : "Вашият Twitter манипулатор",
+    "New user" : "Нов потребител",
+    "User backend" : "Потребителски сървър",
     "You do not have permissions to see the details of this user" : "Нямате права да виждате подробности за този потребител",
-    "Add new password" : "Въведете новата парола",
-    "Add new email address" : "Смени адреса на елетронната поща",
+    "Add user to group" : "Добавяне на потребител към група",
     "Set user as admin for" : "Задаване на потребителя като администратор за",
     "Select user quota" : "Изберете потребителска квота",
-    "Toggle user actions menu" : "Превключване на менюто за действия на потребител",
     "Delete user" : "Изтриване",
     "Wipe all devices" : "Изтрии всички устройства",
     "Disable user" : "Деактивирай",
     "Enable user" : "Активиране",
-    "Edit User" : "Редактиране на потребител",
-    "Will be autogenerated" : "Ще се генерира автоматично",
-    "Add a new user" : "Добавяне на новия потребител",
-    "No users in here" : "Тук няма потребители",
+    "Toggle user actions menu" : "Превключване на менюто за действия на потребител",
+    "Show user backend" : "Показване на потребителския сървър",
     "Name your device" : "Име на устройството",
     "Server error while trying to add WebAuthn device" : "Грешка в сървъра при опит за добавяне на WebAuthn устройство",
-    "{license}-licensed" : "{license}-лицензиран",
     "by {author}\n{license}" : "от {author}\n{license}",
-    "Enter group name" : "Въведете име на групата",
-    "Add group" : "Нова група",
     "Active users" : "Активни потребители",
     "Disabled users" : "Деактивирани потребители",
-    "Default quota:" : "Стандартна квота:",
-    "Show Languages" : "Показвай ползвания език",
-    "Show user backend" : "Показване на потребителския сървър",
-    "Send email to new user" : "Изпращай писмо към нов потребител",
-    "Not saved" : "Не е запазено",
-    "Twitter" : "Twitter",
     "Not available as federation has been disabled for your account, contact your system administrator if you have any questions" : "Не е налично, тъй като федерирането е деактивирано за вашия профил, свържете се с вашия системен администратор, ако имате въпроси.",
     "Not available as publishing user specific data to the lookup server is not allowed, contact your system administrator if you have any questions" : "Не е налично, тъй като публикуването на специфични потребителски данни на сървъра за търсене не е разрешено, свържете се с вашия системен администратор, ако имате въпроси",
     "Show to logged in users only" : "Показване само на влезли потребители",
-    "Enable untested app" : "Включване (нетествано приложение)",
-    "SMTP Username" : "SMTP потребител",
-    "Expire after" : "Изтича след",
-    "day(s)" : "ден(и)",
-    "Exclude groups from password requirements:" : "Изключване на групит от изискванията за парола:",
-    "Set default expiration date" : "Задайте дата на изтичане по подразбиране",
-    "Exclude groups from creating link shares:" : "Изключване на групи от създаване на споделяния на връзки:",
-    "Exclude groups from sharing" : "Забрани групи да споделят",
-    "These groups will still be able to receive shares, but not to initiate them." : "Тези групи ще могат да получават споделения, но няма да могат самите те да споделят."
+    "SMTP Username" : "SMTP потребител"
 },
 "nplurals=2; plural=(n != 1);");
