@@ -6,12 +6,13 @@ OC.L10N.register(
     "Translate" : "ແປ",
     "Offline" : "ອັອບລາຍ",
     "Saving …" : "ກຳລັງບັນທຶກ",
+    "Link" : "ລິງ",
     "Cancel" : "ຍົກເລີກ",
     "Replace" : "ປ່ຽນແທນ",
+    "Edit" : "ແກ້ໄຂ",
     "Info" : "ຂໍ້ມຸນ",
     "Success" : "ຄວາມສໍາເລັດ",
     "Warning" : "ແຈ້ງເຕືອນ",
-    "Edit" : "ແກ້ໄຂ",
-    "Link copied" : "ສຳເນົາລິງ"
+    "Details" : "ລາຍລະອຽດ"
 },
 "nplurals=1; plural=0;");
