@@ -39,10 +39,13 @@ OC.L10N.register(
     "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "次のボタンをクリックして、パスワードをリセットしてください。 パスワードリセットをリクエストしていない場合は、このメールを無視してください。",
     "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "パスワードをリセットするには、次のリンクをクリックしてください。 パスワードリセットをリクエストしていない場合は、このメールを無視してください。",
     "Reset your password" : "パスワードをリセット",
-    "Requested task type does not exist" : "要求されたタスクの種類が存在しません",
-    "Necessary language model provider is not available" : "必要な言語モデルプロバイダーが利用できません",
+    "The given provider is not available" : "指定されたプロバイダは使用できません",
     "Task not found" : "タスクは見つかりません",
     "Internal error" : "内部エラー",
+    "Not found" : "見つかりませんでした",
+    "Bad request" : "Bad request",
+    "Requested task type does not exist" : "要求されたタスクの種類が存在しません",
+    "Necessary language model provider is not available" : "必要な言語モデルプロバイダーが利用できません",
     "No text to image provider is available" : "テキストを画像に変換するプロバイダーはありません",
     "Image not found" : "画像が見つかりません",
     "No translation provider available" : "利用可能な翻訳プロバイダーがありません",
@@ -95,15 +98,45 @@ OC.L10N.register(
     "Continue to {productName}" : "{productName} に進む",
     "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["アップデートできました。%n秒で {productName}にリダイレクトします。"],
     "Applications menu" : "アプリケーションメニュー",
+    "Apps" : "アプリ",
     "More apps" : "さらにアプリ",
-    "Currently open" : "編集中",
     "_{count} notification_::_{count} notifications_" : ["通知 {count} 件"],
     "No" : "いいえ",
     "Yes" : "はい",
+    "Federated user" : "フェデレーションユーザー",
+    "user@your-nextcloud.org" : "user@your-nextcloud.org",
+    "Create share" : "共有を作成",
+    "The remote URL must include the user." : "リモートURLにはユーザーを含める必要があります。",
+    "Invalid remote URL." : "無効なリモートURLです。",
+    "Failed to add the public link to your Nextcloud" : "このNextcloudに公開リンクを追加できませんでした",
+    "Direct link copied to clipboard" : "クリップボードにコピーされた直接リンク",
+    "Please copy the link manually:" : "手動でリンクをコピーしてください：",
     "Custom date range" : "カスタム日付の範囲",
     "Pick start date" : "開始日を指定",
     "Pick end date" : "終了日を指定",
     "Search in date range" : "日付の範囲で検索",
+    "Search in current app" : "現在のアプリケーションで検索",
+    "Clear search" : "検索をクリア",
+    "Search everywhere" : "あらゆる場所を検索",
+    "Unified search" : "統合検索",
+    "Search apps, files, tags, messages" : "アプリ、ファイル、タグ、メッセージを検索",
+    "Places" : "場所",
+    "Date" : "日付",
+    "Today" : "今日",
+    "Last 7 days" : "7日以内",
+    "Last 30 days" : "30日以内",
+    "This year" : "今年",
+    "Last year" : "去年",
+    "Search people" : "人物を検索",
+    "People" : "人間",
+    "Filter in current view" : "現在のビューでフィルタ",
+    "Results" : "結果",
+    "Load more results" : "次の結果を読み込む",
+    "Search in" : "検索対象",
+    "Searching …" : "検索しています…",
+    "Start typing to search" : "入力して検索を開始します",
+    "No matching results" : "一致する結果はありません",
+    "Between ${this.dateFilter.startFrom.toLocaleDateString()} and ${this.dateFilter.endAt.toLocaleDateString()}" : "${this.dateFilter.startFrom.toLocaleDateString()} と ${this.dateFilter.endAt.toLocaleDateString()} の間",
     "Log in" : "ログイン",
     "Logging in …" : "ログイン中...",
     "Server side authentication failed!" : "サーバーサイドの認証に失敗しました！",
@@ -117,8 +150,8 @@ OC.L10N.register(
     "Wrong login or password." : "ログイン名またはパスワードが間違っています。",
     "This account is disabled" : "アカウントが無効化されています",
     "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "あなたのIPから複数の無効なログイン試行が検出されました。 したがって、次回のログインは最大30秒間抑制されます。",
-    "Login with username or email" : "ログインするユーザー名またはメールアドレス",
-    "Login with username" : "ログインするユーザー名",
+    "Account name or email" : "アカウント名またはメールアドレス",
+    "Account name" : "アカウント名",
     "Log in with a device" : "デバイスを使ってログインする",
     "Login or email" : "ログイン名またはEメール",
     "Your account is not setup for passwordless login." : "あなたのアカウントはパスワードなしでログインできるように設定されていません。",
@@ -138,11 +171,11 @@ OC.L10N.register(
     "Recommended apps" : "推奨アプリ",
     "Loading apps …" : "アプリを読み込み中…",
     "Could not fetch list of apps from the App Store." : "App Storeからアプリのリストを取得できませんでした。",
-    "Installing apps …" : "アプリをインストールしています…",
     "App download or installation failed" : "アプリのダウンロードまたはインストールに失敗しました",
     "Cannot install this app because it is not compatible" : "アプリの互換性がないため、インストールできません",
     "Cannot install this app" : "このアプリはインストールできません",
     "Skip" : "スキップ",
+    "Installing apps …" : "アプリをインストールしています…",
     "Install recommended apps" : "推奨アプリをインストール",
     "Schedule work & meetings, synced with all your devices." : "すべての端末と同期して、仕事と会議をスケジュールに組み込みます",
     "Keep your colleagues and friends in one place without leaking their private info." : "個人情報を漏らさずに、同僚や友人をまとめて保管します。",
@@ -150,6 +183,8 @@ OC.L10N.register(
     "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "チャット、ビデオ通話、画面共有、オンラインミーティング、ウェブ会議 - ブラウザーとモバイルアプリで。",
     "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Collabora Online上に構築された、共同作業ドキュメント、スプレッドシート、およびプレゼンテーション",
     "Distraction free note taking app." : "集中モードメモアプリ",
+    "Settings menu" : "メニュー設定",
+    "Avatar of {displayName}" : "{displayName} のアバター",
     "Search contacts" : "連絡先を検索",
     "Reset search" : "検索をリセットする",
     "Search contacts …" : "連絡先を検索...",
@@ -161,14 +196,11 @@ OC.L10N.register(
     "Looking for {term} …" : "{term} を確認中 ...",
     "Search starts once you start typing and results may be reached with the arrow keys" : "入力が始まると検索が始まり、矢印キーで検索結果を表示することができます",
     "Search for {name} only" : "{name}のみを検索",
-    "Start typing to search" : "入力して検索を開始します",
     "Loading more results …" : "次の結果を読み込み中 ...",
-    "Load more results" : "次の結果を読み込む",
     "Search" : "検索",
     "No results for {query}" : "{query}の検索結果はありません",
     "Press Enter to start searching" : "Enterキーを押して検索を開始",
     "An error occurred while searching for {type}" : "{type} の検索中にエラーが発生しました",
-    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["検索には、{minSearchLength}文字以上が必要です"],
     "Forgot password?" : "パスワードをお忘れですか?",
     "Back to login form" : "ログイン画面に戻る",
     "Back" : "戻る",
@@ -179,31 +211,13 @@ OC.L10N.register(
     "You have not added any info yet" : "まだ情報が追加されていません",
     "{user} has not added any info yet" : "{user}が、まだ情報を追加していません",
     "Error opening the user status modal, try hard refreshing the page" : "ユーザーステータスモーダルを開くときにエラーが発生しました。ページを更新してみてください",
-    "Unified search" : "統合検索",
-    "Search apps, files, tags, messages" : "アプリ、ファイル、タグ、メッセージを検索",
-    "Search {types} …" : "{types} を検索…",
-    "Places" : "場所",
-    "Date" : "日付",
-    "Today" : "今日",
-    "Last 7 days" : "7日以内",
-    "Last 30 days" : "30日以内",
-    "This year" : "今年",
-    "Last year" : "去年",
-    "Search people" : "人物を検索",
-    "Not found" : "見つかりませんでした",
-    "People" : "人間",
-    "Filter in current view" : "現在のビューでフィルタ",
-    "Search in" : "検索対象",
-    "Searching …" : "検索しています…",
-    "No matching results" : "一致する結果はありません",
-    "Between ${this.dateFilter.startFrom.toLocaleDateString()} and ${this.dateFilter.endAt.toLocaleDateString()}" : "${this.dateFilter.startFrom.toLocaleDateString()} と ${this.dateFilter.endAt.toLocaleDateString()} の間",
+    "More actions" : "その他のアクション",
     "This browser is not supported" : "お使いのブラウザーはサポートされていません",
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "お使いのブラウザーはサポート対象外です。新しいバージョンにアップグレードするかサポートされているブラウザーへ切り替えてください",
     "Continue with this unsupported browser" : "サポート対象外のブラウザーで継続する",
     "Supported versions" : "サポート対象バージョン",
     "{name} version {version} and above" : "{name} バージョン {version} 以上が対象",
-    "Settings menu" : "メニュー設定",
-    "Avatar of {displayName}" : "{displayName} のアバター",
+    "Search {types} …" : "{types} を検索…",
     "Choose {file}" : "{file}を選択",
     "Choose" : "選択",
     "Copy to {target}" : "{target} にコピー",
@@ -256,7 +270,6 @@ OC.L10N.register(
     "No tags found" : "タグが見つかりません",
     "Personal" : "個人",
     "Accounts" : "アカウント",
-    "Apps" : "アプリ",
     "Admin" : "管理",
     "Help" : "ヘルプ",
     "Access forbidden" : "アクセスが禁止されています",
@@ -273,6 +286,7 @@ OC.L10N.register(
     "The server was unable to complete your request." : "サーバーは要求を完了できませんでした。",
     "If this happens again, please send the technical details below to the server administrator." : "再びこのようなことが起こった場合は、以下の技術情報をサーバー管理者に送ってください。",
     "More details can be found in the server log." : "詳細は、サーバーのログを確認してください。",
+    "For more details see the documentation ↗." : "詳細については、ドキュメントを参照してください ↗",
     "Technical details" : "技術詳細",
     "Remote Address: %s" : "リモートアドレス: %s",
     "Request ID: %s" : "リクエスト ID: %s",
@@ -371,53 +385,7 @@ OC.L10N.register(
     "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the {linkstart}documentation ↗{linkend}." : "Webサーバーで \"{url}\" が解決されるように正しく設定されていません。詳細については、{linkstart}ドキュメント↗{linkend}をご覧ください。",
     "Your web server is not properly set up to resolve \"{url}\". This is most likely related to a web server configuration that was not updated to deliver this folder directly. Please compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx at it's {linkstart}documentation page ↗{linkend}. On Nginx those are typically the lines starting with \"location ~\" that need an update." : "Webサーバーで \"{url}\" が解決されるように正しく設定されていません。これは、このフォルダーを直接配信するように更新されていないWebサーバー構成が影響している可能性があります。構成を、Apacheの \".htaccess\" にある設定済みの書き換えルールまたはNginxのドキュメントの{linkstart}ドキュメントページ↗{linkend}で提供されているルールと比較してください。 Nginxでは、これらは通常、修正が必要な \"location〜\" で始まる行です。",
     "Your web server is not properly set up to deliver .woff2 files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustement to also deliver .woff2 files. Compare your Nginx configuration to the recommended configuration in our {linkstart}documentation ↗{linkend}." : "Webサーバーで.woff2ファイルが配信されるように適切に設定されていません。これは通常、Nginx構成の問題です。 Nextcloud 15の場合、.woff2ファイルも配信するように調整する必要があります。 Nginx構成を{linkstart}ドキュメント↗{linkend}の推奨構成と比較してください。",
-    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHPのシステム環境変数が正しく設定されていないようです。getenv(\"PATH\") コマンドでテストして何も値を返さないことを確認してください。",
-    "Please check the {linkstart}installation documentation ↗{linkend} for PHP configuration notes and the PHP configuration of your server, especially when using php-fpm." : "特にphp-fpmを使用する場合は、{linkstart}インストールドキュメント↗{linkend}でPHP構成に関する注意事項とサーバーのPHP構成を確認してください。",
-    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "\"config\"は読み取り専用になってます。そのためにWEBインターフェースで設定できません可能性があります。さらに、更新時に\"config\"ファイルを書き込み権限を与えることが必要",
-    "You have not set or verified your email server configuration, yet. Please head over to the {mailSettingsStart}Basic settings{mailSettingsEnd} in order to set them. Afterwards, use the \"Send email\" button below the form to verify your settings." : "メールサーバーの設定が未設定または未確認です。{mailSettingsStart}基本設定{mailSettingsEnd}で設定を行ってください。その後、フォームの下にある「メールを送信」ボタンで設定を確認してください。",
-    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "あなたのデータベースは \"READ COMMITED\" トランザクション分離レベルで動作していません。このことにより複数のアクションが平行して実行される場合に問題が起こる可能性があります。",
-    "The PHP module \"fileinfo\" is missing. It is strongly recommended to enable this module to get the best results with MIME type detection." : "PHP のモジュール 'fileinfo' が見つかりません。mimeタイプの検出を精度良く行うために、このモジュールを有効にすることを強くお勧めします。",
-    "Your remote address was identified as \"{remoteAddress}\" and is brute-force throttled at the moment slowing down the performance of various requests. If the remote address is not your address this can be an indication that a proxy is not configured correctly. Further information can be found in the {linkstart}documentation ↗{linkend}." : "あなたのIPアドレスは、\"{remoteAddress}\" として認識されており、現在ブルートフォース対策機能により様々なリクエストのパフォーマンスが低下しています。IPアドレスがあなたのアドレスでない場合、プロキシが正しく設定されていない可能性があります。詳細は{linkstart}ドキュメント{linkend}をご覧ください。",
-    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems. See the {linkstart}documentation ↗{linkend} for more information." : "トランザクションファイルロックが無効になっているため、競合状態に問題が発生する可能性があります。これらの問題を回避するには、config.phpで \"filelocking.enabled\" を有効にします。詳細については、{linkstart}ドキュメント↗{linkend}を参照してください。",
-    "The database is used for transactional file locking. To enhance performance, please configure memcache, if available. See the {linkstart}documentation ↗{linkend} for more information." : "データベースがトランザクションファイルロックに使われています。パフォーマンスをあげるには、可能であればメモリーのキャッシュを設定してください。詳しくは {linkstart}こちらの文書↗{linkend}をご覧ください。",
-    "Please make sure to set the \"overwrite.cli.url\" option in your config.php file to the URL that your users mainly use to access this Nextcloud. Suggestion: \"{suggestedOverwriteCliURL}\". Otherwise there might be problems with the URL generation via cron. (It is possible though that the suggested URL is not the URL that your users mainly use to access this Nextcloud. Best is to double check this in any case.)" : "config.phpファイルの \"overwrite.cli.url \"オプションに、ユーザーが主にこのNextcloudにアクセスするために使用するURLを設定しておいてください。提案します。\"{suggestedOverwriteCliURL}\"を指定してください。そうしないと、cronによるURLの生成に問題が発生する可能性があります。(ただし、提案されたURLは、あなたのユーザーが主にこの NextcloudにアクセスするためのURLではない可能性があります。いずれにせよ、ダブルチェックするのがベストです)。",
-    "Your installation has no default phone region set. This is required to validate phone numbers in the profile settings without a country code. To allow numbers without a country code, please add \"default_phone_region\" with the respective {linkstart}ISO 3166-1 code ↗{linkend} of the region to your config file." : "ご使用のシステムには、デフォルトの電話地域が設定されていません。これは、国コードなしでプロファイル設定の電話番号を検証するために必要です。国コードなしで番号を許可するには、地域のそれぞれの{linkstart} ISO3166-1コード↗{linkend}とともに \"default_phone_region\" を設定ファイルに追加してください。",
-    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "CLI から cronジョブを実行することができませんでした。次の技術的なエラーが発生しています：",
-    "Last background job execution ran {relativeTime}. Something seems wrong. {linkstart}Check the background job settings ↗{linkend}." : "最後のバックグラウンドジョブの実行は{relativeTime}を実行しました。何かがおかしいようです。 {linkstart}バックグラウンドジョブの設定を確認してください↗{linkend}。",
-    "This is the unsupported community build of Nextcloud. Given the size of this instance, performance, reliability and scalability cannot be guaranteed. Push notifications are limited to avoid overloading our free service. Learn more about the benefits of Nextcloud Enterprise at {linkstart}https://nextcloud.com/enterprise{linkend}." : "本サーバーはNextcloudのサポートがないコミュニティビルドで動いています。実行中の規模でのパフォーマンス、信頼性、スケーラビリティを保証するものではありません。プッシュ通知は無料サービスへ負荷がかからないように制限されています。Nextcloud Enterpriseのメリットについては、{linkstart}https://nextcloud.com/enterprise{linkend}を参照してください。",
-    "This server has no working internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the internet to enjoy all features." : "このサーバーにはインターネット接続がありません。複数のエンドポイントに到達できませんでした。 つまり、外部ストレージのマウント、アップデートに関する通知、サードパーティ製アプリのインストールなどの機能の一部は機能しません。 リモートからファイルにアクセスしたり、通知メールを送信したりすることもできません。インターネットへの接続を確立できれば、すべての機能を利用することができます。",
-    "No memory cache has been configured. To enhance performance, please configure a memcache, if available. Further information can be found in the {linkstart}documentation ↗{linkend}." : "メモリーキャッシュが構成されていません。パフォーマンスを向上させるために、可能な場合はmemcacheを構成してください。詳細については、{linkstart}ドキュメント↗{linkend}をご覧ください。",
-    "No suitable source for randomness found by PHP which is highly discouraged for security reasons. Further information can be found in the {linkstart}documentation ↗{linkend}." : "PHPで利用する乱数に適切なソースがありません。これは、セキュリティ上の理由から全く推奨されていません。詳細については、{linkstart}ドキュメント↗{linkend}をご覧ください。",
-    "You are currently running PHP {version}. Upgrade your PHP version to take advantage of {linkstart}performance and security updates provided by the PHP Group ↗{linkend} as soon as your distribution supports it." : "あなたは現在、PHP {version} を使用しています。ディストリビューションでサポートされたら、すぐにPHPのバージョンをアップグレードして、{linkstart}PHPグループ↗の提供するパフォーマンスとセキュリティメリット{linkend}を享受してください。",
-    "PHP 8.0 is now deprecated in Nextcloud 27. Nextcloud 28 may require at least PHP 8.1. Please upgrade to {linkstart}one of the officially supported PHP versions provided by the PHP Group ↗{linkend} as soon as possible." : "PHP 8.0 は Nextcloud 27 で非推奨になりました。Nextcloud 28 では少なくとも PHP 8.1 が必要になる場合があります。できるだけ早く、{linkstart}PHP グループ が提供する、正式にサポートされている PHP バージョンのいずれか↗{linkend} にアップグレードしてください。",
-    "The reverse proxy header configuration is incorrect, or you are accessing Nextcloud from a trusted proxy. If not, this is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud. Further information can be found in the {linkstart}documentation ↗{linkend}." : "リバースプロキシヘッダーの構成が正しくないか、信頼できるプロキシからNextcloudにアクセスしています。そうでない場合、これはセキュリティに問題があり、攻撃者がNextcloudを表示できるようにIPアドレスを偽装することができます。詳細については、{linkstart}ドキュメント↗{linkend}をご覧ください。",
-    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the {linkstart}memcached wiki about both modules ↗{linkend}." : "Memcachedが分散キャッシュとして設定されていますが、間違ったPHPモジュール \"memcache\" がインストールされています。 \\OC\\Memcache\\Memcachedは \"memcached\" のみをサポートし、\"memcache\" はサポートしません。は、{linkstart} 両方のモジュールについてはmemcached wiki↗{linkend}を参照してください。",
-    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in the {linkstart1}documentation ↗{linkend}. ({linkstart2}List of invalid files…{linkend} / {linkstart3}Rescan…{linkend})" : "一部のファイルは整合性チェックに合格していません。この問題を解決する方法の詳細については、{linkstart1}ドキュメント↗{linkend}をご覧ください。 ({linkstart2}無効なファイルのリスト…{linkend} / {linkstart3}再スキャン…{linkend})",
-    "The PHP OPcache module is not properly configured. See the {linkstart}documentation ↗{linkend} for more information." : "PHP OPcacheモジュールが正しく設定されていません。詳細は {linkstart} ドキュメント {linkend} を参照してください。",
-    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "PHP 関数 \"set_time_limit\" は使用できません。これにより実行スクリプトが途中で停止されて、インストールを破壊する可能性があります。この機能を有効にすることを強くお勧めします。",
-    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "プロフィール写真と設定インターフェースが壊れているため、PHPはFreeTypeをサポートしていません。",
-    "Missing index \"{indexName}\" in table \"{tableName}\"." : "テーブル \"{tableName}\"のインデックス \"{indexName}\"が見つかりません。",
-    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "データベースにいくつかのインデックスがありません。 大きなテーブルにインデックスを追加すると、自動的に追加されないまでに時間がかかる可能性があるためです。 \"occ db:add-missing-indices\"を実行することによって、インスタンスが実行し続けている間にそれらの欠けているインデックスを手動で追加することができます。 インデックスが追加されると、それらのテーブルへのクエリは通常はるかに速くなります。",
-    "Missing primary key on table \"{tableName}\"." : "テーブル \"{tableName}\"にプライマリーキーがありません。",
-    "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "データベースにいくつかのプライマリーキーがありません。大きなテーブルにプライマリーキーを追加するには時間がかかる可能性があるため、自動的に追加されません。 \"occ db:add-missing-primary-keys\" を実行することにより、インスタンスを動かしたままで足りないプライマリーキーを手動で追加することができます。",
-    "Missing optional column \"{columnName}\" in table \"{tableName}\"." : "テーブル \"{tableName}\" にオプションのカラム \"{columnName}\" が存在しません。",
-    "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "データベースにはオプションのカラムがいくつかありません。大きなテーブルにカラムを追加するには時間がかかるため、オプションのカラムは自動的に追加されませんでした。\"occ db:add-missing-columns\"を実行することで、不足しているカラムはインスタンスの実行中に手動で追加することができます。カラムが追加されると、応答性や使い勝手が改善される可能性があります。",
-    "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them." : "このインスタンスには推奨されるPHPモジュールがいくつかありません。 パフォーマンスの向上と互換性の向上のために、それらをインストールすることを強くお勧めします。",
-    "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "テーマ別アプリは有効ですが、PHPモジュール「imagick」が有効ではありません。ファビコン生成を正しく行うには、このモジュールをインストールし、有効化する必要があります。",
-    "The PHP modules \"gmp\" and/or \"bcmath\" are not enabled. If you use WebAuthn passwordless authentication, these modules are required." : "PHP モジュール \"gmp\" および \"bcmath\" が有効になっていない。WebAuthnパスワードレス認証を利用する場合は、これらのモジュールが必要です。",
-    "It seems like you are running a 32-bit PHP version. Nextcloud needs 64-bit to run well. Please upgrade your OS and PHP to 64-bit! For further details read {linkstart}the documentation page ↗{linkend} about this." : "このシステムは32ビット版のPHPで動いているようです。Nextcloudを正常に動かすには64ビット版が必要です。OSとPHPを64ビット版にアップグレードしてください！詳細は{linkstart}こちらのドキュメント ↗{linkend}をご覧ください。",
-    "Module php-imagick in this instance has no SVG support. For better compatibility it is recommended to install it." : "このインスタンスのphp-imagickモジュールはSVGをサポートしていません。互換性の向上のために、インストールすることをお勧めします。",
-    "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running \"occ db:convert-filecache-bigint\" those pending changes could be applied manually. This operation needs to be made while the instance is offline. For further details read {linkstart}the documentation page about this ↗{linkend}." : "データベース内の一部のカラムで、大きなint型への変換が欠落しています。大きなテーブルのカラムタイプの変更には時間がかかるため、それらは自動的に変更されませんでした。occ db:convert-filecache-bigint\" を実行することで、それらの保留中の変更を手動で適用することができます。この操作は、インスタンスがオフラインの時に行う必要があります。詳しくは{linkstart}このドキュメントページ{linkend}を読んでください。",
-    "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "SQLiteがデータベースとして使用されています。大規模な運用では別のデータベースに切り替えることをお勧めします。",
-    "This is particularly recommended when using the desktop client for file synchronisation." : "これは、ファイル同期にデスクトップクライアントを使用する場合に特に推奨されます。",
-    "To migrate to another database use the command line tool: \"occ db:convert-type\", or see the {linkstart}documentation ↗{linkend}." : "別のデータベースに移行するには、コマンドラインツールを使います。\"occ db:convert-type\" または {linkstart}ドキュメント {linkend} を参照してください。",
-    "The PHP memory limit is below the recommended value of 512MB." : "PHPのメモリ制限が推奨値の512MB以下です。",
-    "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:" : "一部のアプリディレクトリは、Webサーバーディレクトリとは異なるユーザーによって所有されています。 アプリが手動でインストールされた場合、これがそのケースに値します。 次のアプリディレクトリの権限を確認します。",
-    "MySQL is used as database but does not support 4-byte characters. To be able to handle 4-byte characters (like emojis) without issues in filenames or comments for example it is recommended to enable the 4-byte support in MySQL. For further details read {linkstart}the documentation page about this ↗{linkend}." : "データベースとしてMySQLを使用していますが、4バイト文字をサポートしていません。ファイル名やコメントなどで4バイト文字（絵文字など）を問題なく扱うためには、MySQLで4バイトサポートを有効にすることが推奨されます。詳細は{linkstart}これに関するドキュメントページ↗{linkend}をお読みください。",
-    "This instance uses an S3 based object store as primary storage. The uploaded files are stored temporarily on the server and thus it is recommended to have 50 GB of free space available in the temp directory of PHP. Check the logs for full details about the path and the available space. To improve this please change the temporary directory in the php.ini or make more space available in that path." : "このインスタンスは、S3ベースのオブジェクトストアをプライマリストレージとして使用します。 アップロードされたファイルは一時的にサーバーに保存されるため、PHPの一時ディレクトリに50 GBの空き容量を確保することをお勧めします。 パスと空き容量についての完全な詳細はログを確認してください。 一時ディレクトリを修正するには、php.iniの一時ディレクトリを変更するか、またはそのパスでより多くのスペースを利用できるようにしてください。",
-    "The temporary directory of this instance points to an either non-existing or non-writable directory." : "このインスタンスで指定している一時ディレクトリは、存在しないか書き込みできないディレクトリです。",
     "You are accessing your instance over a secure connection, however your instance is generating insecure URLs. This most likely means that you are behind a reverse proxy and the overwrite config variables are not set correctly. Please read {linkstart}the documentation page about this ↗{linkend}." : "安全な接続でインスタンスにアクセスしていますが、インスタンスは安全でないURLを生成しています。これは、リバースプロキシの背後にあり、構成設定変数が正しく上書きされていない可能性があります。これについては、{linkend}ドキュメントページ↗{linkstart}をお読みください。",
-    "This instance is running in debug mode. Only enable this for local development and not in production environments." : "このインスタンスはデバッグ モードで実行されています。これはローカル開発の場合にのみ有効にし、運用環境では有効にしないでください。",
     "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "データディレクトリやファイルがインターネットからアクセスされている可能性があります。.htaccessファイルが機能していません。データディレクトリにアクセスできないようにWebサーバーを設定するか、データディレクトリをWebサーバーのドキュメントルートの外に移動することを強くお勧めします。",
     "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "\"{header}\" HTTPヘッダーが \"{expected}\"に設定されていません。 これらは潜在的なセキュリティまたはプライバシーのリスクになります。この設定を調整することをお勧めします",
     "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "\"{header}\" HTTPヘッダーが \"{expected}\"に設定されていません。 一部の機能は正しく機能しない可能性があります。この設定を調整することを推奨します。",
@@ -425,46 +393,23 @@ OC.L10N.register(
     "The \"{header}\" HTTP header is not set to \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" or \"{val5}\". This can leak referer information. See the {linkstart}W3C Recommendation ↗{linkend}." : "HTTPヘッダの\"{header}\"に\"{val1}\"、\"{val2}\"、\"{val3}\"、\"{val4}\"、\"{val5}\"が設定されていません。これにより、リファラー情報が漏洩する可能性があります。 {linkstart} W3C勧告↗{linkend}を参照してください。",
     "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the {linkstart}security tips ↗{linkend}." : "Strict-Transport-Security \"HTTP ヘッダーの秒数が少なくとも\"{seconds}\" に設定されていません。セキュリティを強化するには、{linkstart}セキュリティのヒント↗{linkend}で説明されているようにHSTSを有効にすることをお勧めします。",
     "Accessing site insecurely via HTTP. You are strongly advised to set up your server to require HTTPS instead, as described in the {linkstart}security tips ↗{linkend}. Without it some important web functionality like \"copy to clipboard\" or \"service workers\" will not work!" : "HTTP 経由で安全ではないサイトにアクセスします。 {linkstart}セキュリティのヒント ↗{linkend} で説明されているように、代わりに HTTPS を要求するようにサーバーを設定することを強くお勧めします。これがないと、「クリップボードにコピー」や「Service Worker」などの一部の重要な Web 機能が動作しません！",
-    "Account name or email" : "アカウント名またはメールアドレス",
+    "Currently open" : "編集中",
     "Wrong username or password." : "ユーザー名またはパスワードが間違っています",
     "User disabled" : "ユーザーは無効です",
+    "Login with username or email" : "ログインするユーザー名またはメールアドレス",
+    "Login with username" : "ログインするユーザー名",
     "Username or email" : "ユーザー名またはメールアドレス",
     "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or account name, check your spam/junk folders or ask your local administration for help." : "このアカウントが存在したら、パスワード変更のメッセージがそのメールアドレスに送信されます。\nもしメールが届いていない場合は、メールアドレスまたはアカウント名を確認するか、メールが迷惑メールフォルダに入っていないか確認するか、もしくは管理者にお問い合わせください。",
-    "Start search" : "検索開始",
-    "Open settings menu" : "設定メニューを開く",
-    "Settings" : "設定",
-    "Avatar of {fullName}" : "{fullName} のアバター",
-    "Show all contacts …" : "すべての連絡先を表示...",
-    "No files in here" : "ここにはファイルがありません",
-    "New folder" : "新しいフォルダー",
-    "No more subfolders in here" : "ここにはサブフォルダーはありません",
-    "Name" : "名前",
-    "Size" : "サイズ",
-    "Modified" : "更新日時",
-    "\"{name}\" is an invalid file name." : "\"{name}\" は無効なファイル名です。",
-    "File name cannot be empty." : "ファイル名を空にすることはできません。",
-    "\"/\" is not allowed inside a file name." : "\"/\" はファイル名に利用できません。",
-    "\"{name}\" is not an allowed filetype" : "\"{name}\" は無効なファイル形式です",
-    "{newName} already exists" : "{newName} はすでに存在します",
-    "Error loading file picker template: {error}" : "ファイル選択テンプレートの読み込みエラー: {error}",
+    "Apps and Settings" : "アプリと設定",
     "Error loading message template: {error}" : "メッセージテンプレートの読み込みエラー: {error}",
-    "Show list view" : "リストビューで表示",
-    "Show grid view" : "グリッドビューで表示",
-    "Pending" : "保留中",
-    "Home" : "ホーム",
-    "Copy to {folder}" : "{folder}へコピー",
-    "Move to {folder}" : "{folder}へ移動",
-    "Authentication required" : "認証が必要です",
-    "This action requires you to confirm your password" : "この操作では、パスワードを確認する必要があります",
-    "Confirm" : "確認",
-    "Failed to authenticate, try again" : "認証に失敗しました。もう一度お試しください",
     "Users" : "ユーザー",
     "Username" : "ユーザー名",
     "Database user" : "データベースのユーザー名",
+    "This action requires you to confirm your password" : "この操作では、パスワードを確認する必要があります",
     "Confirm your password" : "パスワードを確認",
+    "Confirm" : "確認",
     "App token" : "アプリのトークン",
     "Alternative log in using app token" : "アプリトークンを使って代替ログイン",
-    "Please use the command line updater because you have a big instance with more than 50 users." : "50人以上が使う大規模システムの場合は、コマンドラインでアップグレードを行ってください。",
-    "Apps and Settings" : "アプリと設定"
+    "Please use the command line updater because you have a big instance with more than 50 users." : "50人以上が使う大規模システムの場合は、コマンドラインでアップグレードを行ってください。"
 },
 "nplurals=1; plural=0;");
