@@ -8,7 +8,7 @@ OC.L10N.register(
     "The file was uploaded" : "文件已上传 ",
     "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "上传的文件超过了 php.ini 中的 upload_max_filesize 指令",
     "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "上传的文件超过了 HTML 表单中指定的 MAX_FILE_SIZE 指令",
-    "The file was only partially uploaded" : "文件只有部分被上传 ",
+    "The file was only partially uploaded" : "文件仅部分上传 ",
     "No file was uploaded" : "没有文件被上传 ",
     "Missing a temporary folder" : "缺少临时文件夹 ",
     "Could not write file to disk" : "无法将文件写入磁盘",
@@ -39,10 +39,13 @@ OC.L10N.register(
     "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "点击下方按钮来重置您的密码。如果您并没有请求密码重置，请忽略这封邮件。",
     "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "点击下方链接重置您的密码。如果您没有请求重置密码，请忽略本邮件。",
     "Reset your password" : "重置您的密码",
-    "Requested task type does not exist" : "请求的任务类型不存在",
-    "Necessary language model provider is not available" : "无必要的语言模型提供程序",
+    "The given provider is not available" : "指定提供者不可用",
     "Task not found" : "找不到任务",
     "Internal error" : "内部错误",
+    "Not found" : "未找到",
+    "Bad request" : "请求错误",
+    "Requested task type does not exist" : "请求的任务类型不存在",
+    "Necessary language model provider is not available" : "无必要的语言模型提供程序",
     "No text to image provider is available" : "没有可用的文字转图像提供者",
     "Image not found" : "未找到图像",
     "No translation provider available" : "没有可用的翻译提供程序",
@@ -95,15 +98,45 @@ OC.L10N.register(
     "Continue to {productName}" : "继续到 {productName}",
     "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["更新成功，%n 秒后您将重定向到 {productName}。"],
     "Applications menu" : "应用程序菜单",
+    "Apps" : "应用",
     "More apps" : "更多的应用程序",
-    "Currently open" : "当前打开",
     "_{count} notification_::_{count} notifications_" : ["{count} 条通知"],
     "No" : "否",
     "Yes" : "是",
+    "Federated user" : "联合云用户",
+    "user@your-nextcloud.org" : "user@your-nextcloud.org",
+    "Create share" : "创建共享",
+    "The remote URL must include the user." : "远程 URL 必须包含用户。",
+    "Invalid remote URL." : "无效远程 URL。",
+    "Failed to add the public link to your Nextcloud" : "添加公开链接到您的Nextcloud失败",
+    "Direct link copied to clipboard" : "直链已复制至粘贴板",
+    "Please copy the link manually:" : "请手动复制链接：",
     "Custom date range" : "自定义日期范围",
     "Pick start date" : "选择起始日期",
     "Pick end date" : "选择结束日期",
     "Search in date range" : "在日期范围内进行搜索",
+    "Search in current app" : "在当前应用程序中搜索",
+    "Clear search" : "清除搜索",
+    "Search everywhere" : "在所有位置搜索",
+    "Unified search" : "统一搜索",
+    "Search apps, files, tags, messages" : "搜索应用程序、文件、标签，信息",
+    "Places" : "地点",
+    "Date" : "日期",
+    "Today" : "今日",
+    "Last 7 days" : "过去 7 天",
+    "Last 30 days" : "过去 30 天",
+    "This year" : "今年",
+    "Last year" : "上年",
+    "Search people" : "搜索人物",
+    "People" : "人物",
+    "Filter in current view" : "在当前视图中筛选",
+    "Results" : "结果",
+    "Load more results" : "加载更多结果",
+    "Search in" : "搜索",
+    "Searching …" : "正在搜索 ...",
+    "Start typing to search" : "开始输入搜索内容",
+    "No matching results" : "无匹配结果",
+    "Between ${this.dateFilter.startFrom.toLocaleDateString()} and ${this.dateFilter.endAt.toLocaleDateString()}" : "介于 ${this.dateFilter.startFrom.toLocaleDateString()} 到 ${this.dateFilter.endAt.toLocaleDateString()} 之间",
     "Log in" : "登录",
     "Logging in …" : "正在登录……",
     "Server side authentication failed!" : "服务端认证失败！",
@@ -117,8 +150,8 @@ OC.L10N.register(
     "Wrong login or password." : "错误的账号或密码",
     "This account is disabled" : "此账号已停用",
     "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "我们检测到您的IP进行了多次无效登录尝试。因此，您的下一次登录最长会延迟30秒。",
-    "Login with username or email" : "使用用户名或邮箱进行登录",
-    "Login with username" : "使用用户名登录",
+    "Account name or email" : "账户名或邮箱地址",
+    "Account name" : "账户名称",
     "Log in with a device" : "使用设备登录",
     "Login or email" : "输入账号或者电子邮件",
     "Your account is not setup for passwordless login." : "您的账号未设置无密码登录。",
@@ -138,11 +171,11 @@ OC.L10N.register(
     "Recommended apps" : "推荐的应用",
     "Loading apps …" : "正在加载应用…",
     "Could not fetch list of apps from the App Store." : "无法从应用商店获取应用列表",
-    "Installing apps …" : "正在安装应用...",
     "App download or installation failed" : "应用下载或安装失败",
     "Cannot install this app because it is not compatible" : "无法安装此应用，因它不兼容",
     "Cannot install this app" : "无法安装此应用",
     "Skip" : "跳过",
+    "Installing apps …" : "正在安装应用...",
     "Install recommended apps" : "安装推荐的应用",
     "Schedule work & meetings, synced with all your devices." : "安排工作和会议，并与您的所有设备同步。",
     "Keep your colleagues and friends in one place without leaking their private info." : "将您的同事和朋友放在一个地方，而不会泄漏他们的私人信息。",
@@ -150,6 +183,8 @@ OC.L10N.register(
     "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "在浏览器和移动设备应用中进行聊天，视频通话，屏幕共享，线上见面和网络会议。",
     "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "基于 Collabora Online 的文档、表格与演示文档。",
     "Distraction free note taking app." : "无干扰的笔记记录应用。",
+    "Settings menu" : "设置菜单",
+    "Avatar of {displayName}" : "{displayName} 的头像",
     "Search contacts" : "搜索联系人",
     "Reset search" : "重置搜索",
     "Search contacts …" : "搜索联系人……",
@@ -161,14 +196,11 @@ OC.L10N.register(
     "Looking for {term} …" : "正在查找{term} ……",
     "Search starts once you start typing and results may be reached with the arrow keys" : "一旦您开始输入，搜索就会开始，您可以使用方向键切换到结果。",
     "Search for {name} only" : "仅搜索 {name}",
-    "Start typing to search" : "开始输入搜索内容",
     "Loading more results …" : "加载更多结果...",
-    "Load more results" : "加载更多结果",
     "Search" : "搜索",
     "No results for {query}" : "没有 '{query}' 的相关结果",
     "Press Enter to start searching" : "按下Enter开始搜索",
     "An error occurred while searching for {type}" : "搜索 {type} 时出错",
-    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["请输入 {minSearchLength} 个字符或更多字符以进行搜索"],
     "Forgot password?" : "忘记密码？",
     "Back to login form" : "回到登录表格",
     "Back" : "返回",
@@ -179,31 +211,13 @@ OC.L10N.register(
     "You have not added any info yet" : "您尚未添加任何信息",
     "{user} has not added any info yet" : "{user} 尚未添加任何信息",
     "Error opening the user status modal, try hard refreshing the page" : "打开用户状态模块时出错，请努力刷新页面",
-    "Unified search" : "统一搜索",
-    "Search apps, files, tags, messages" : "搜索应用程序、文件、标签，信息",
-    "Search {types} …" : "搜索 {类型} …",
-    "Places" : "地点",
-    "Date" : "日期",
-    "Today" : "今日",
-    "Last 7 days" : "过去 7 天",
-    "Last 30 days" : "过去 30 天",
-    "This year" : "今年",
-    "Last year" : "上年",
-    "Search people" : "搜索人物",
-    "Not found" : "未找到",
-    "People" : "人物",
-    "Filter in current view" : "在当前视图中筛选",
-    "Search in" : "搜索",
-    "Searching …" : "正在搜索 ...",
-    "No matching results" : "无匹配结果",
-    "Between ${this.dateFilter.startFrom.toLocaleDateString()} and ${this.dateFilter.endAt.toLocaleDateString()}" : "介于 ${this.dateFilter.startFrom.toLocaleDateString()} 到 ${this.dateFilter.endAt.toLocaleDateString()} 之间",
+    "More actions" : "更多操作 ",
     "This browser is not supported" : "您的浏览器不受支持！",
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "您的浏览器不受支持。请升级至较新或受支持的版本。",
     "Continue with this unsupported browser" : "继续使用该过时的浏览器",
     "Supported versions" : "支持的版本",
     "{name} version {version} and above" : "{name} 版本 {version} 及更高",
-    "Settings menu" : "设置菜单",
-    "Avatar of {displayName}" : "{displayName} 的头像",
+    "Search {types} …" : "搜索 {类型} …",
     "Choose {file}" : "选择 {file}",
     "Choose" : "选择",
     "Copy to {target}" : "复制到 {target}",
@@ -256,7 +270,6 @@ OC.L10N.register(
     "No tags found" : "标签未找到",
     "Personal" : "个人",
     "Accounts" : "账户",
-    "Apps" : "应用",
     "Admin" : "管理",
     "Help" : "帮助",
     "Access forbidden" : "访问禁止",
@@ -273,6 +286,7 @@ OC.L10N.register(
     "The server was unable to complete your request." : "服务器不能完成您的请求。",
     "If this happens again, please send the technical details below to the server administrator." : "如果再次发生这种情况，请将下面的技术详细信息发送给服务器管理员。",
     "More details can be found in the server log." : "更多细节可以在服务器日志中找到。",
+    "For more details see the documentation ↗." : "查阅说明文档以获得更多信息 ↗。",
     "Technical details" : "技术细节",
     "Remote Address: %s" : "远程地址：%s",
     "Request ID: %s" : "请求 ID：%s",
@@ -371,53 +385,7 @@ OC.L10N.register(
     "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the {linkstart}documentation ↗{linkend}." : "您的网页服务器未正确设置以解析“{url}”。更多信息请参见{linkstart}文档↗{linkend}。",
     "Your web server is not properly set up to resolve \"{url}\". This is most likely related to a web server configuration that was not updated to deliver this folder directly. Please compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx at it's {linkstart}documentation page ↗{linkend}. On Nginx those are typically the lines starting with \"location ~\" that need an update." : "您的网页服务器没有正确配置以解析“{url}”。这很可能与 web 服务器配置没有更新以发布这个文件夹有关。请将您的配置与 Apache 的“.htaccess”文件中的默认重写规则或与这个{linkstart}文档页面↗{linkend}中提供的 Nginx 配置进行比较。在 Nginx 配置中通常需要修改以“location ~”开头的行。",
     "Your web server is not properly set up to deliver .woff2 files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustement to also deliver .woff2 files. Compare your Nginx configuration to the recommended configuration in our {linkstart}documentation ↗{linkend}." : "您的网页服务器未正确设置以服务 .woff2 文件。这通常是一个 Nginx 配置的问题。对于 Nextcloud 15，需要更改一个设置才能发布 .woff2 文件。请将您的 Nginx 配置与我们{linkstart}文档↗{linkend}中的推荐配置进行比较。",
-    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP 的安装似乎不正确，无法访问系统环境变量。getenv(\"PATH\") 函数测试返回了一个空值。",
-    "Please check the {linkstart}installation documentation ↗{linkend} for PHP configuration notes and the PHP configuration of your server, especially when using php-fpm." : "请检查{linkstart}安装文档 ↗{linkend}中关于 PHP 的配置说明和您服务器上的 PHP 配置，特别是在使用 php-fpm 时。",
-    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "只读配置已启用。这可以在浏览器界面保护配置。另外，每次更新时需手动赋予该文件写权限。",
-    "You have not set or verified your email server configuration, yet. Please head over to the {mailSettingsStart}Basic settings{mailSettingsEnd} in order to set them. Afterwards, use the \"Send email\" button below the form to verify your settings." : "您还没有设置或验证您的电子邮件服务器配置。请前往{mailSettingsStart}基本设置{mailSettingsEnd}，以便进行设置。之后，使用表单下方的 \"发送电子邮件 \"按钮来验证您的设置。",
-    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "数据库没有运行在“READ COMMITTED”事务隔离级别。当多项操作同时执行时将产生问题。",
-    "The PHP module \"fileinfo\" is missing. It is strongly recommended to enable this module to get the best results with MIME type detection." : "未找到 PHP 的“fileinfo”模块。强烈推荐启用该模块，从而获得更好的 MIME 类型探测结果。",
-    "Your remote address was identified as \"{remoteAddress}\" and is brute-force throttled at the moment slowing down the performance of various requests. If the remote address is not your address this can be an indication that a proxy is not configured correctly. Further information can be found in the {linkstart}documentation ↗{linkend}." : "您的远程地址为「{remoteAddress}」，目前正在受到攻击限速，系统请求性能降低。如果这非您的远程地址，则可能表明代理配置不正确。您可以在{linkstart}文档↗{linkend}中找到更多信息。",
-    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems. See the {linkstart}documentation ↗{linkend} for more information." : "事务文件锁被禁用，这可能导致并发争用相关的问题。在 config.php 中启用“filelocking.enabled”选项来规避这些问题。请参考{linkstart}文档↗{linkend}获取更多信息。",
-    "The database is used for transactional file locking. To enhance performance, please configure memcache, if available. See the {linkstart}documentation ↗{linkend} for more information." : "数据库被用于事务文件锁。为了增强性能，请设置memcache（如果可用）。获取更多信息请参见{linkstart}文档↗{linkend}。",
-    "Please make sure to set the \"overwrite.cli.url\" option in your config.php file to the URL that your users mainly use to access this Nextcloud. Suggestion: \"{suggestedOverwriteCliURL}\". Otherwise there might be problems with the URL generation via cron. (It is possible though that the suggested URL is not the URL that your users mainly use to access this Nextcloud. Best is to double check this in any case.)" : "请确保在您的 config.php 文件中设置“overwrite.cli.url”选项为您的用户主要用于访问该 Nextcloud 的 URL。建议：“{suggestedOverwriteCliURL}”。否则可能会出现通过 cron 生成 URL 的问题。（但此处建议的 URL 有可能不是您的用户主要用来访问此 Nextcloud 的 URL。在任何情况下最好都仔细检查。）",
-    "Your installation has no default phone region set. This is required to validate phone numbers in the profile settings without a country code. To allow numbers without a country code, please add \"default_phone_region\" with the respective {linkstart}ISO 3166-1 code ↗{linkend} of the region to your config file." : "您的安装没有设置默认的电话区域。这对验证个人资料页面中缺少国家代码的电话号码而言是必需的。要允许没有国家代码的电话号码，请添加相应的“default_phone_region”到您的配置文件中。允许的国家和地区请参阅 {linkstart}ISO 3166-1 code ↗{linkend}。",
-    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "无法通过 CLI 执行计划任务，请查看以下技术错误：",
-    "Last background job execution ran {relativeTime}. Something seems wrong. {linkstart}Check the background job settings ↗{linkend}." : "上一个后台作业执行运行了 {relativeTime}。好像出了什么问题。{linkstart}检查后台作业设置 ↗{linkend}",
-    "This is the unsupported community build of Nextcloud. Given the size of this instance, performance, reliability and scalability cannot be guaranteed. Push notifications are limited to avoid overloading our free service. Learn more about the benefits of Nextcloud Enterprise at {linkstart}https://nextcloud.com/enterprise{linkend}." : "这是一个不受支持的 Nextcloud 社区版构建。鉴于此实例的大小，其性能、可靠性与可拓展性无法得到保证。为了避免我们提供的免费服务负载过重，通知推送功能受到限制。请至 {linkstart}https://nextcloud.com/enterprise{linkend} 获取更多关于企业版 Nextcloud 的资讯。",
-    "This server has no working internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the internet to enjoy all features." : "此服务器没有工作的互联网连接：无法访问多个端点。这意味着一些功能，如挂载外部存储、更新或安装第三方应用程序的通知将无法工作。远程访问文件和发送通知邮件也可能无法工作。建立从这个服务器到互联网的连接，以享受所有功能。",
-    "No memory cache has been configured. To enhance performance, please configure a memcache, if available. Further information can be found in the {linkstart}documentation ↗{linkend}." : "内存缓存未配置。为了提升性能，请尽量配置内存缓存。更多信息请参见{linkstart}文档↗{linkend}。",
-    "No suitable source for randomness found by PHP which is highly discouraged for security reasons. Further information can be found in the {linkstart}documentation ↗{linkend}." : "PHP找不到合适的随机性来源，出于安全原因，这是强烈不推荐的。 更多信息可以在{linkstart}文档↗{linkend}中找到。",
-    "You are currently running PHP {version}. Upgrade your PHP version to take advantage of {linkstart}performance and security updates provided by the PHP Group ↗{linkend} as soon as your distribution supports it." : "您当前正在运行 PHP 版本 {version}。我们建议您在您的操作系统发行版支持PHP新版本的时候进行升级，以获得{linkstart}来自 PHP 官方的性能和安全更新↗{linkend}。",
-    "PHP 8.0 is now deprecated in Nextcloud 27. Nextcloud 28 may require at least PHP 8.1. Please upgrade to {linkstart}one of the officially supported PHP versions provided by the PHP Group ↗{linkend} as soon as possible." : "Nextcloud 27已弃用PHP 8.0。Nextcloud 28可能需要PHP 8.1或更高版本。请尽快升级至一个 {linkstart}PHP Group ↗{linkend}提供官方支持的版本。",
-    "The reverse proxy header configuration is incorrect, or you are accessing Nextcloud from a trusted proxy. If not, this is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud. Further information can be found in the {linkstart}documentation ↗{linkend}." : "反向代理头部配置错误，或者您正在通过可信的代理访问 Nextcloud。如果您不是通过可信代理访问 Nextcloud，那这是一个安全问题，它可能允许攻击者通过伪装其IP地址以访问 Nextcloud。更多信息请查看{linkstart}文档↗{linkend}。",
-    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the {linkstart}memcached wiki about both modules ↗{linkend}." : "Memcached 被配置为分布式缓存，但安装了错误的 PHP 模块 \"memcache\"。\\OC\\Memcache\\Memcached 只支持 \"memcached\" 不支持 \"memcache\"。见 {linkstart} 有关两者的 memcached 维基 ↗{linkend}.",
-    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in the {linkstart1}documentation ↗{linkend}. ({linkstart2}List of invalid files…{linkend} / {linkstart3}Rescan…{linkend})" : "一些文件未通过完整性检查。有关如何解决这一问题的进一步信息可在 {linkstart1}文档 ↗{linkend}中找到。({linkstart2}无效文件列表 ...{linkend} / {linkstart3}重新扫描 ...{linkend})",
-    "The PHP OPcache module is not properly configured. See the {linkstart}documentation ↗{linkend} for more information." : "PHP OPcache 模块没有正确配置。更多信息请参见{linkstart}文档 ↗{linkend}。",
-    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "PHP函数“set_time_limit”不可用。 这可能会导致脚本在执行过程中暂停，从而导致安装中断。 我们强烈建议启用此功能。",
-    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "您的 PHP 没有 FreeType 支持，导致配置文件图片和设置界面中断。",
-    "Missing index \"{indexName}\" in table \"{tableName}\"." : "在数据表“{tableName}”中无法找到索引“{indexName}”。",
-    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "数据库丢失了一些索引。由于给大的数据表添加索引会耗费一些时间，因此程序没有自动对其进行修复。您可以在 Nextcloud 运行时通过命令行手动执行“occ db:add-missing-indices”命令修复丢失的索引。索引修复后会大大提高相应表的查询速度。",
-    "Missing primary key on table \"{tableName}\"." : "在数据表“{tableName}”中缺少主键。",
-    "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "数据库缺少一些主键。由于在大型数据表上添加主键可能需要一些时间，因此程序没有自动添加。通过运行“occ db:add-missing-primary-keys”，这些缺失的主键可以在实例持续运行时手动添加。",
-    "Missing optional column \"{columnName}\" in table \"{tableName}\"." : "表 “{tableName}” 中缺少可选列 “{columnName}”。",
-    "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "数据库缺少一些可选列。 由于在大表上添加列可能会花费一些时间，因此在可以选择时不会自动添加列。 通过运行“occ db:add-missing-columns”，可以在实例继续运行时手动添加那些缺少的列。 添加列后，某些功能可能会提高响应速度或可用性。",
-    "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them." : "该实例缺失了一些推荐的 PHP 模块。为提高性能和兼容性，我们强烈建议安装它们。",
-    "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "PHP 模块“imagick”没有被启用，尽管已启用了主题程序。为了使收藏图标正常生成，您需要安装并启用这个模块。",
-    "The PHP modules \"gmp\" and/or \"bcmath\" are not enabled. If you use WebAuthn passwordless authentication, these modules are required." : "PHP 模块“gmp”和/或“bcmath”未被启用。如果您使用 WebAuthn 无密码验证，这些模块是必需的。",
-    "It seems like you are running a 32-bit PHP version. Nextcloud needs 64-bit to run well. Please upgrade your OS and PHP to 64-bit! For further details read {linkstart}the documentation page ↗{linkend} about this." : "您似乎正在使用32位的PHP版本。Nextcloud需要64位的PHP版本以便良好运行。请升级您的系统和PHP版本至64位！点击{linkstart}文档页面 ↗{linkend}阅读更多信息。",
-    "Module php-imagick in this instance has no SVG support. For better compatibility it is recommended to install it." : "此实例中的 php-imagick 模块不支持 SVG。为了获得更好的兼容性，建议安装它。",
-    "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running \"occ db:convert-filecache-bigint\" those pending changes could be applied manually. This operation needs to be made while the instance is offline. For further details read {linkstart}the documentation page about this ↗{linkend}." : "数据库中的一些列缺少到 big int 格式的转换。由于改变大表的列类型可能需要一些时间，所以它们没有被自动改变。通过运行“occ db:convert-filecache-bigint”，可以手动应用这些未决的变化。这个操作需要在实例离线的情况下进行。更多详情请阅读 {linkstart}有关于此的文档页面 ↗{linkend}。",
-    "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "您当前正在使用 SQLite 作为后端数据库。在大型服务中，我们推荐您改用其它的后端数据库。",
-    "This is particularly recommended when using the desktop client for file synchronisation." : "如果您使用桌面客户端同步文件，我们非常建议您这样做。",
-    "To migrate to another database use the command line tool: \"occ db:convert-type\", or see the {linkstart}documentation ↗{linkend}." : "要迁移到另一个数据库，请使用命令行工具“occ db:convert-type”或参见 {linkstart}文档 ↗{linkend}",
-    "The PHP memory limit is below the recommended value of 512MB." : "PHP 内存限制低于建议值 512MB。",
-    "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:" : "有些应用程序目录是由与 Web 服务器不同的用户拥有的。如果应用程序是手动安装的，情况可能是这样的。检查以下应用程序目录的权限：",
-    "MySQL is used as database but does not support 4-byte characters. To be able to handle 4-byte characters (like emojis) without issues in filenames or comments for example it is recommended to enable the 4-byte support in MySQL. For further details read {linkstart}the documentation page about this ↗{linkend}." : "MySQL 被用作数据库，但不支持 4 字节字符。要能够在文件名或评论中正确处理 4 字节字符 （如 emoji），建议在 MySQL 中启用 4 字节支持。关于更多详细信息，您可以阅读{linkstart}有关此问题的文档页 ↗{linkend}。",
-    "This instance uses an S3 based object store as primary storage. The uploaded files are stored temporarily on the server and thus it is recommended to have 50 GB of free space available in the temp directory of PHP. Check the logs for full details about the path and the available space. To improve this please change the temporary directory in the php.ini or make more space available in that path." : "此实例使用基于 S3 的对象存储作为主存储。上传的文件会临时存放在服务器上，所以建议 PHP 的临时目录有 50 GB 的可用空间。路径和可用空间的详情请查看日志。要改善此状况请修改 php.ini 文件中的临时目录路径或增加该路径的可用空间。",
-    "The temporary directory of this instance points to an either non-existing or non-writable directory." : "此实例的临时目录指向一个不存在或不可写的目录。",
     "You are accessing your instance over a secure connection, however your instance is generating insecure URLs. This most likely means that you are behind a reverse proxy and the overwrite config variables are not set correctly. Please read {linkstart}the documentation page about this ↗{linkend}." : "您正通过安全连接访问您的实例，然而您的实例正生成不安全的 URL。这很可能意味着您位于反向代理的后面，覆盖的配置变量没有正确设置。可以阅读{linkstart}有关此问题的文档页 ↗{linkend}",
-    "This instance is running in debug mode. Only enable this for local development and not in production environments." : "此实例正在调试模式下运行。仅在本地开发而非生产环境时启用该模式。",
     "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "您的数据目录和文件似乎可以从互联网访问。这是因为 .htaccess 文件无效。强烈建议您配置您的 web 服务器，使数据目录不再可访问，或将数据目录移到 web 服务器文档根目录之外。",
     "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "HTTP 请求头“{header}”没有配置为“{expected}”。这是一个潜在的安全或隐私风险，我们建议您调整这项设置。",
     "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "HTTP 请求头“{header}”没有配置为“{expected}”。某些功能可能无法正常工作，因此建议相应地调整此设置。",
@@ -425,46 +393,23 @@ OC.L10N.register(
     "The \"{header}\" HTTP header is not set to \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" or \"{val5}\". This can leak referer information. See the {linkstart}W3C Recommendation ↗{linkend}." : "“{header}”HTTP 头未设置为“{val1}”、“{val2}”、“{val3}”、“{val4}”或“{val5}”。这可能会泄露 refer 信息。请参考 {linkstart}W3C 建议 ↗{linkend}。",
     "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the {linkstart}security tips ↗{linkend}." : "“Strict-Transport-Security”HTTP 头未设为至少“{seconds}”秒。为了提高安全性，建议启用 HSTS，参考步骤见{linkstart}安全小贴士 ↗{linkend}。",
     "Accessing site insecurely via HTTP. You are strongly advised to set up your server to require HTTPS instead, as described in the {linkstart}security tips ↗{linkend}. Without it some important web functionality like \"copy to clipboard\" or \"service workers\" will not work!" : "您正在通过不安全的 HTTP 访问网站。我们强烈建议您在服务器上启用 HTTPS，更多资讯请参见{linkstart}安全贴士 ↗{linkend}。如果不这样设置，某些重要网页功能，如“复制到剪贴板”和“Service Workers”将无法工作。",
-    "Account name or email" : "账户名或邮箱地址",
+    "Currently open" : "当前打开",
     "Wrong username or password." : "错误的用户名或密码。",
     "User disabled" : "用户不可用",
+    "Login with username or email" : "使用用户名或邮箱进行登录",
+    "Login with username" : "使用用户名登录",
     "Username or email" : "用户名或邮箱",
     "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or account name, check your spam/junk folders or ask your local administration for help." : "如果此账户存在，一封密码重置邮件已发送到其电子邮件地址。如果您未收到，请验证您的电子邮件地址和/或账户名称，并检查您的垃圾邮件文件夹，或向您的本地管理员求助。",
-    "Start search" : "开始搜索",
-    "Open settings menu" : "打开设置菜单",
-    "Settings" : "设置",
-    "Avatar of {fullName}" : "{fullName}的头像",
-    "Show all contacts …" : "显示所有联系人……",
-    "No files in here" : "未找到文件",
-    "New folder" : "新建文件夹",
-    "No more subfolders in here" : "没有更多的子文件夹",
-    "Name" : "名称",
-    "Size" : "大小",
-    "Modified" : "已修改",
-    "\"{name}\" is an invalid file name." : "“{name}”是一个无效的文件名。",
-    "File name cannot be empty." : "文件名不能为空。",
-    "\"/\" is not allowed inside a file name." : "文件名不能包含“/”。",
-    "\"{name}\" is not an allowed filetype" : "“{name}”不是允许的文件类型",
-    "{newName} already exists" : "{newName} 已经存在",
-    "Error loading file picker template: {error}" : "加载文件选择模板出错：{error}",
+    "Apps and Settings" : "应用程序以及设置",
     "Error loading message template: {error}" : "加载消息模板出错：{error}",
-    "Show list view" : "显示列表视图",
-    "Show grid view" : "显示网格视图",
-    "Pending" : "等待",
-    "Home" : "首页 ",
-    "Copy to {folder}" : "复制到 {folder}",
-    "Move to {folder}" : "移动到 {folder}",
-    "Authentication required" : "需要验证身份",
-    "This action requires you to confirm your password" : "此操作需要你确认你的密码",
-    "Confirm" : "确认",
-    "Failed to authenticate, try again" : "验证失败，请重试",
     "Users" : "用户",
     "Username" : "用户名",
     "Database user" : "数据库用户",
+    "This action requires you to confirm your password" : "此操作需要你确认你的密码",
     "Confirm your password" : "确认您的密码",
+    "Confirm" : "确认",
     "App token" : "App 令牌",
     "Alternative log in using app token" : "使用应用程序令牌替代登录",
-    "Please use the command line updater because you have a big instance with more than 50 users." : "请使用命令行更新，因为您有一个超过 50 个用户的大型实例。",
-    "Apps and Settings" : "应用程序以及设置"
+    "Please use the command line updater because you have a big instance with more than 50 users." : "请使用命令行更新，因为您有一个超过 50 个用户的大型实例。"
 },
 "nplurals=1; plural=0;");
