@@ -8,7 +8,7 @@ OC.L10N.register(
     "The file was uploaded" : "檔案已上傳",
     "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "上傳的檔案大小超過 php.ini 當中 upload_max_filesize 參數的設定",
     "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "上傳的檔案大小超過 HTML 表單中 MAX_FILE_SIZE 參數的設定",
-    "The file was only partially uploaded" : "檔案僅部分上傳",
+    "The file was only partially uploaded" : "檔案僅部分上傳成功",
     "No file was uploaded" : "沒有檔案被上傳",
     "Missing a temporary folder" : "找不到暫存資料夾",
     "Could not write file to disk" : "無法將檔案寫入磁碟",
@@ -39,10 +39,13 @@ OC.L10N.register(
     "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "點選下方的按鈕來重設您的密碼。若您沒有要求重設密碼，請不用理會此電子郵件。",
     "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "點取下方的連結以重設您的密碼。如果您沒有要求重設密碼的話，請不用理會此電子郵件。",
     "Reset your password" : "重設密碼",
-    "Requested task type does not exist" : "請求的任務類型不存在",
-    "Necessary language model provider is not available" : "沒有必要的語言模型提供者",
+    "The given provider is not available" : "指定的提供者不可用",
     "Task not found" : "找不到任務",
     "Internal error" : "內部錯誤",
+    "Not found" : "未找到",
+    "Bad request" : "請求無效",
+    "Requested task type does not exist" : "請求的任務類型不存在",
+    "Necessary language model provider is not available" : "沒有必要的語言模型提供者",
     "No text to image provider is available" : "沒有可用的文字轉影像提供者",
     "Image not found" : "找不到圖像",
     "No translation provider available" : "沒有可用翻譯提供者",
@@ -95,15 +98,45 @@ OC.L10N.register(
     "Continue to {productName}" : "前往 {productName}",
     "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["更新成功，將在 %n 秒後重導向至 {productName}。"],
     "Applications menu" : "應用程式選項單",
+    "Apps" : "應用程式",
     "More apps" : "更多應用程式",
-    "Currently open" : "目前開啟",
     "_{count} notification_::_{count} notifications_" : ["{count} 個通知"],
     "No" : "否",
     "Yes" : "是",
+    "Federated user" : "聯盟用戶",
+    "user@your-nextcloud.org" : "user@your-nextcloud.org",
+    "Create share" : "創建分享",
+    "The remote URL must include the user." : "遠端 URL 必須包含用戶。",
+    "Invalid remote URL." : "無效的遠端 URL。",
+    "Failed to add the public link to your Nextcloud" : "無法將公開連結加入您的 Nextcloud",
+    "Direct link copied to clipboard" : "直接連結已複製到剪貼簿",
+    "Please copy the link manually:" : "請手動複製連結：",
     "Custom date range" : "自訂日期範圍",
     "Pick start date" : "挑選開始日期",
     "Pick end date" : "挑選結束日期",
     "Search in date range" : "在日期範圍內搜尋",
+    "Search in current app" : "在目前的應用程式中搜尋",
+    "Clear search" : "清除搜尋",
+    "Search everywhere" : "到處搜尋",
+    "Unified search" : "統一搜尋",
+    "Search apps, files, tags, messages" : "搜尋應用程式、檔案、標籤、訊息",
+    "Places" : "地點",
+    "Date" : "日期",
+    "Today" : "今日",
+    "Last 7 days" : "過去7日",
+    "Last 30 days" : "過去30日",
+    "This year" : "今年",
+    "Last year" : "去年",
+    "Search people" : "搜尋人仕",
+    "People" : "人物",
+    "Filter in current view" : "目前檢視裡的篩選條件",
+    "Results" : "結果",
+    "Load more results" : "載入更多結果",
+    "Search in" : "搜尋",
+    "Searching …" : "正在搜尋……",
+    "Start typing to search" : "輸入文字以檢索",
+    "No matching results" : "無相符結果",
+    "Between ${this.dateFilter.startFrom.toLocaleDateString()} and ${this.dateFilter.endAt.toLocaleDateString()}" : "介於 ${this.dateFilter.startFrom.toLocaleDateString()} 到 ${this.dateFilter.endAt.toLocaleDateString()} 間",
     "Log in" : "登入",
     "Logging in …" : "正在登入 …",
     "Server side authentication failed!" : "伺服器端認證失敗！",
@@ -117,8 +150,8 @@ OC.L10N.register(
     "Wrong login or password." : "登入名稱或密碼錯誤。",
     "This account is disabled" : "此帳戶已停用",
     "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "您的 IP 多次嘗試登入無效。因此下一次登入將會被延時30秒。請耐心等待一段時間後再試。",
-    "Login with username or email" : "以用戶名稱或電郵地址登入",
-    "Login with username" : "以用戶名稱登入",
+    "Account name or email" : "帳戶名稱或電郵地址",
+    "Account name" : "帳戶名稱",
     "Log in with a device" : "使用免密碼裝置登入",
     "Login or email" : "帳戶或電子郵件",
     "Your account is not setup for passwordless login." : "你的賬號尚未設定免密碼登入。",
@@ -138,11 +171,11 @@ OC.L10N.register(
     "Recommended apps" : "推薦的應用程式",
     "Loading apps …" : "正在載入應用程式…",
     "Could not fetch list of apps from the App Store." : "無法從應用程式商店抓取應用程式清單。",
-    "Installing apps …" : "正在安裝應用程式…",
     "App download or installation failed" : "應用程式下載或是安裝失敗",
     "Cannot install this app because it is not compatible" : "應用程式無法安裝，因為不相容",
     "Cannot install this app" : "無法安裝此應用程式",
     "Skip" : "略過",
+    "Installing apps …" : "正在安裝應用程式…",
     "Install recommended apps" : "安裝推薦的應用程式",
     "Schedule work & meetings, synced with all your devices." : "排定工作和會議時間，並與您的所有裝置同步",
     "Keep your colleagues and friends in one place without leaking their private info." : "將您的同事和朋友的聯繫整合在一處，且不洩漏他們的個人資訊",
@@ -150,6 +183,8 @@ OC.L10N.register(
     "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "對話、視訊電話、螢幕分享、線上會議與網路研討會 - 實現於你的瀏覽器與手機 apps 之中。",
     "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "基於 Collabora Online 構建的協作文件、試算表和演講文稿。",
     "Distraction free note taking app." : "無干擾的筆記應用程式。",
+    "Settings menu" : "設定選單",
+    "Avatar of {displayName}" : "{displayName} 的虛擬化身",
     "Search contacts" : "搜尋聯絡人",
     "Reset search" : "重置搜尋",
     "Search contacts …" : "搜尋聯絡人…",
@@ -161,14 +196,11 @@ OC.L10N.register(
     "Looking for {term} …" : "正在搜尋 {term} …",
     "Search starts once you start typing and results may be reached with the arrow keys" : "一旦您開始輸入，搜尋就會開始，您可以使用方向鍵到達結果",
     "Search for {name} only" : "只搜尋 {name}",
-    "Start typing to search" : "輸入文字以檢索",
     "Loading more results …" : "正在載入更多結果...",
-    "Load more results" : "載入更多結果",
     "Search" : "搜尋",
     "No results for {query}" : "{query} 查詢沒有結果",
     "Press Enter to start searching" : "按 Enter 開始搜尋",
     "An error occurred while searching for {type}" : "搜尋 {type} 時發生錯誤",
-    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["請輸入 {minSearchLength} 個或以上字元搜尋"],
     "Forgot password?" : "忘記密碼？",
     "Back to login form" : "回到登入表格",
     "Back" : "返回",
@@ -179,31 +211,13 @@ OC.L10N.register(
     "You have not added any info yet" : "您尚未新增任何資訊",
     "{user} has not added any info yet" : "{user} 尚未新增任何資訊",
     "Error opening the user status modal, try hard refreshing the page" : "打開用戶狀態模式時出錯，請嘗試刷新頁面",
-    "Unified search" : "統一搜尋",
-    "Search apps, files, tags, messages" : "搜尋應用程式、檔案、標籤、訊息",
-    "Search {types} …" : "搜尋 {types} 中 …",
-    "Places" : "地點",
-    "Date" : "日期",
-    "Today" : "今日",
-    "Last 7 days" : "過去7日",
-    "Last 30 days" : "過去30日",
-    "This year" : "今年",
-    "Last year" : "去年",
-    "Search people" : "搜尋人仕",
-    "Not found" : "未找到",
-    "People" : "人物",
-    "Filter in current view" : "目前檢視裡的篩選條件",
-    "Search in" : "搜尋",
-    "Searching …" : "正在搜尋……",
-    "No matching results" : "無相符結果",
-    "Between ${this.dateFilter.startFrom.toLocaleDateString()} and ${this.dateFilter.endAt.toLocaleDateString()}" : "介於 ${this.dateFilter.startFrom.toLocaleDateString()} 到 ${this.dateFilter.endAt.toLocaleDateString()} 間",
+    "More actions" : "更多操作",
     "This browser is not supported" : "不支援此瀏覽器",
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "不支援您的瀏覽器。請升級至較新或受支援的版本。",
     "Continue with this unsupported browser" : "繼續使用此不受支援的瀏覽器",
     "Supported versions" : "支援的版本",
     "{name} version {version} and above" : "{name} 的版本 {version} 及更新",
-    "Settings menu" : "設定選單",
-    "Avatar of {displayName}" : "{displayName} 的虛擬化身",
+    "Search {types} …" : "搜尋 {types} 中 …",
     "Choose {file}" : "選擇 {file}",
     "Choose" : "選擇",
     "Copy to {target}" : "複製到 {target}",
@@ -256,7 +270,6 @@ OC.L10N.register(
     "No tags found" : "查無標籤",
     "Personal" : "個人",
     "Accounts" : "帳戶",
-    "Apps" : "應用程式",
     "Admin" : "管理",
     "Help" : "說明",
     "Access forbidden" : "存取被拒",
@@ -273,6 +286,7 @@ OC.L10N.register(
     "The server was unable to complete your request." : "伺服器無法完成你的請求。",
     "If this happens again, please send the technical details below to the server administrator." : "如果此問題重複發生，請寄送技術資訊給管理員。",
     "More details can be found in the server log." : "伺服器記錄檔裡面有更多細節",
+    "For more details see the documentation ↗." : "要取得更多細節資訊，請參閱說明書 ↗。",
     "Technical details" : "技術細節",
     "Remote Address: %s" : "遠端位置：%s",
     "Request ID: %s" : "請求編號：%s",
@@ -371,53 +385,7 @@ OC.L10N.register(
     "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the {linkstart}documentation ↗{linkend}." : "您的網絡伺服器未正確設置為解析“ {url}”。可以在 {linkstart} 說明書↗{linkend} 中找到更多信息。",
     "Your web server is not properly set up to resolve \"{url}\". This is most likely related to a web server configuration that was not updated to deliver this folder directly. Please compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx at it's {linkstart}documentation page ↗{linkend}. On Nginx those are typically the lines starting with \"location ~\" that need an update." : "您的網絡伺服器未正確設置為解析“ {url}”。這很可能與未更新為直接傳送此資料夾的Web伺服器配置有關。請將您的配置與Apache的“。htaccess”中提供的重寫規則或Nginx文檔中提供的重寫規則（位於{linkstart}文檔頁面↗{linkend}）進行比較。在Nginx上，通常以“ location ~”開頭的行需要更新。",
     "Your web server is not properly set up to deliver .woff2 files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustement to also deliver .woff2 files. Compare your Nginx configuration to the recommended configuration in our {linkstart}documentation ↗{linkend}." : "您的 Web 伺服器未正確設置為傳遞 .woff2 檔案。這通常是 Nginx 配置的問題。對於Nextcloud 15，需要進行調整以同時交付 .woff2 檔案。將您的 Nginx 配置與我們的{linkstart}文檔↗{linkend}中的推薦配置進行比較。",
-    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP 設定似乎不完整，導致無法正確取得系統環境變數，因為偵測到 getenv(\"PATH\") 回傳資料為空值",
-    "Please check the {linkstart}installation documentation ↗{linkend} for PHP configuration notes and the PHP configuration of your server, especially when using php-fpm." : "請查看 {linkstart}安裝文檔↗{linkend}，以獲取PHP配置說明和伺服器的PHP配置，尤其是在使用 php-fpm 時。",
-    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "「唯讀設定檔」已經啟用，這樣可以防止來自網頁端的設定操作，每次需要更改設定時，都需要手動將設定檔暫時改為可讀寫。",
-    "You have not set or verified your email server configuration, yet. Please head over to the {mailSettingsStart}Basic settings{mailSettingsEnd} in order to set them. Afterwards, use the \"Send email\" button below the form to verify your settings." : "您尚未設置或驗證您的電郵伺服器配置。請前往 {mailSettingsStart} 基本設置 {mailSettingsEnd} 進行設置。然後使用表單下方的【發送電郵】按鈕驗證您的設置。",
-    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "您的數據庫並未使用 \"READ COMMITTED\" 的交易隔離等級。當有多個操作平行進行時，這可能會造成問題。",
-    "The PHP module \"fileinfo\" is missing. It is strongly recommended to enable this module to get the best results with MIME type detection." : "未偵測到 PHP 模組 'fileinfo'。強烈建議啟用這個模組，以取得最好的 MIME 檔案類型偵測支援。",
-    "Your remote address was identified as \"{remoteAddress}\" and is brute-force throttled at the moment slowing down the performance of various requests. If the remote address is not your address this can be an indication that a proxy is not configured correctly. Further information can be found in the {linkstart}documentation ↗{linkend}." : "您的遠端地址被識別為「{remoteAddress}」，且目前正受到強力限制，導致降低了各種請求的效能。若遠端地址不是您的地址，可能代表代理伺服器設定不正確。可以在{linkstart}文件 ↗{linkend} 中找到進一步的資訊。",
-    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems. See the {linkstart}documentation ↗{linkend} for more information." : "交易性檔案上鎖已停用，這可能導致爭用條件問題。在config.php中啟用 “filelocking.enabled” 可以避免這些問題。有關更多信息，請參見{linkstart}文檔↗{linkend}。",
-    "The database is used for transactional file locking. To enhance performance, please configure memcache, if available. See the {linkstart}documentation ↗{linkend} for more information." : "數據庫用於事務檔案鎖定。為提高性能，請配置 memcache（如果可用）。有關詳細信息，請參閱{linkstart}說明書 ↗{linkend}。",
-    "Please make sure to set the \"overwrite.cli.url\" option in your config.php file to the URL that your users mainly use to access this Nextcloud. Suggestion: \"{suggestedOverwriteCliURL}\". Otherwise there might be problems with the URL generation via cron. (It is possible though that the suggested URL is not the URL that your users mainly use to access this Nextcloud. Best is to double check this in any case.)" : "請確保將 config.php 文件中的“overwrite.cli.url”選項設置為您的用戶主要用於訪問此 Nextcloud 的 URL。建議：“{suggestedOverwriteCliURL}”。否則，通過 cron 生成的 URL 可能會出現問題。（但是，建議的 URL 可能不是您的用戶主要用於訪問此 Nextcloud 的 URL。最好是仔細檢查以防萬一。）",
-    "Your installation has no default phone region set. This is required to validate phone numbers in the profile settings without a country code. To allow numbers without a country code, please add \"default_phone_region\" with the respective {linkstart}ISO 3166-1 code ↗{linkend} of the region to your config file." : "你並未設置手機國際冠碼。設置後用戶在個人檔案設定手機號碼時不必再輸入國際冠碼。若要這樣做，請新增「default_phone_region」於設定檔，允許的國家及地區請參閱 {linkstart}ISO 3166-1 code ↗{linkend} 清單。",
-    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : " 無法透過 CLI 來執行排程工作，發生以下技術性錯誤：",
-    "Last background job execution ran {relativeTime}. Something seems wrong. {linkstart}Check the background job settings ↗{linkend}." : "最後一次後台作業是於 {relativeTime} 前執行，似乎很久沒有執行了，有點問題。{linkstart}請檢查背景工作設定 ↗{linkend}。",
-    "This is the unsupported community build of Nextcloud. Given the size of this instance, performance, reliability and scalability cannot be guaranteed. Push notifications are limited to avoid overloading our free service. Learn more about the benefits of Nextcloud Enterprise at {linkstart}https://nextcloud.com/enterprise{linkend}." : "這是不受支援的 Nextcloud 社群版建置。鑑於此站台的大小，無法保證效能、可靠程度與延展性。推播通知已被限制，以避免我們的免費服務負載過重。請至 {linkstart}nextcloud.com/enterprise{linkend} 取得更多關於 Nextcloud 企業版的資訊。",
-    "This server has no working internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the internet to enjoy all features." : "此伺服器沒有可用的互聯網連接（無法訪問多個端點）。 這意味著某些功能（例如掛載外部存儲、有關更新或安裝第三方應用程式的通知）將無法使用。 遠端存取檔案和發送通知電子郵件也可能不起作用。 請建立從此伺服器到互聯網的連接以享受所有功能。",
-    "No memory cache has been configured. To enhance performance, please configure a memcache, if available. Further information can be found in the {linkstart}documentation ↗{linkend}." : "尚未配置內存緩存。為了提高性能，請配置內存緩存（如有）。可以在 {linkstart}說明書↗{linkend} 中找到更多資訊。",
-    "No suitable source for randomness found by PHP which is highly discouraged for security reasons. Further information can be found in the {linkstart}documentation ↗{linkend}." : "由於安全原因，強烈建議不要使用PHP找到適合隨機性的來源。可以在{linkstart}文檔↗{linkend}中找到更多信息。",
-    "You are currently running PHP {version}. Upgrade your PHP version to take advantage of {linkstart}performance and security updates provided by the PHP Group ↗{linkend} as soon as your distribution supports it." : "您當前正在運行PHP {version}。只要您的發行版支持，請升級PHP版本以利用 {linkstart}PHP Group↗提供的性能和安全更新{linkend}。",
-    "PHP 8.0 is now deprecated in Nextcloud 27. Nextcloud 28 may require at least PHP 8.1. Please upgrade to {linkstart}one of the officially supported PHP versions provided by the PHP Group ↗{linkend} as soon as possible." : "Nextcloud 27 現已棄用 PHP 8.0。Nextcloud 28 需要 PHP 8.1 或更高版本。請盡快升級到 {linkstart} PHP Group ↗{linkend} 提供的官方支持的 PHP 版本之一。",
-    "The reverse proxy header configuration is incorrect, or you are accessing Nextcloud from a trusted proxy. If not, this is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud. Further information can be found in the {linkstart}documentation ↗{linkend}." : "反向代理標頭（reverse proxy header）配置不正確，或者您正在從受信任的代理（trusted proxy）存取 Nextcloud。如果不是這樣，則這是一個安全問題，並且可以使攻擊者欺騙其對 Nextcloud 可見的IP地址。可以在{linkstart}文檔↗{linkend}中找到更多資訊。",
-    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the {linkstart}memcached wiki about both modules ↗{linkend}." : "Memcached 配置為分布式緩存，但是安裝了錯誤的PHP模塊 “memcache”。\\OC\\Memcache\\Memcached 僅支持 “memcached”，不支持 “memcache”。有關這兩個模塊的信息，請參見{linkstart}內存緩存wiki {linkend}。",
-    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in the {linkstart1}documentation ↗{linkend}. ({linkstart2}List of invalid files…{linkend} / {linkstart3}Rescan…{linkend})" : "某些檔案未通過完整性檢查。有關如何解決此問題的更多信息，請參見{linkstart1}文檔↗{linkend}。（{linkstart2}無效檔案清單…{linkend} / {linkstart3}重新掃描…{linkend}）",
-    "The PHP OPcache module is not properly configured. See the {linkstart}documentation ↗{linkend} for more information." : "PHP OPcache 模塊配置不正確。 請參閱 {linkstart} 文檔 ↗{linkend} 了解更多信息。",
-    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "無法取得 PHP 中的 \"set_time_limit\" 函式。這可能導致執行過程被終止並造成不完整安裝。我們強烈建議啟用該函式。",
-    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "您的 PHP 並未啟用 FreeType 支援，導致大頭貼產生器和設定界面無法使用。",
-    "Missing index \"{indexName}\" in table \"{tableName}\"." : "在數據庫表 \"{tableName}\" 中，找不到索引值 \"{indexName}\"。",
-    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "數據庫缺少某些索引值。由於將索引添加到大型數據庫表可能需要一段時間，安裝程序因此不會自動添加索引。您可執行 “occ db:add-missing-indices” 來手動新增那些缺少的索引值。當索引值新增完成後，查詢的速度通常會變得快許多。",
-    "Missing primary key on table \"{tableName}\"." : "數據表 \"{tableName}\" 缺少主鍵。",
-    "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "數據庫缺少一些主鍵。由於在大表上添加主鍵可能會花費一些時間，因此我們不會自動添加主鍵。通過運行 “occ db:add-missing-primary-keys”，可以在實例繼續運行的同時手動添加那些缺少的主鍵。",
-    "Missing optional column \"{columnName}\" in table \"{tableName}\"." : "數據表 {tableName} 中缺少可選列 {columnName} 。",
-    "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "數據庫遺失了一些欄位，然而添加主鍵這個動作將在肥大的數據庫花費許多時間，故我們將不會自動處理這項問題。藉由執行「occ db:add-missing-columns」手動添加這些欄位將能在系統持續運作時修復這個問題。添加可選欄位將提高系統回應速度和可用性。",
-    "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them." : "您的 Nextcloud 缺少了某些建議的 PHP 模組。為了提升效能與相容性，強烈建議您安裝這些 PHP 模組。",
-    "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "雖然已啟用佈景主題應用程式，但並未啟用 PHP 模組「imagick」。為了讓 favicon 產生流程正常運作，您必須安裝並啟用此模組。",
-    "The PHP modules \"gmp\" and/or \"bcmath\" are not enabled. If you use WebAuthn passwordless authentication, these modules are required." : "未啟用 PHP 模組「gmp」與「bcmath」。若您要使用 WebAuthn 免密碼驗證，這些模組就是必要的。",
-    "It seems like you are running a 32-bit PHP version. Nextcloud needs 64-bit to run well. Please upgrade your OS and PHP to 64-bit! For further details read {linkstart}the documentation page ↗{linkend} about this." : "您好像正在運行 32 位 PHP 版本。Nextcloud 需要 64 位才能運行良好。請將您的操作系統和 PHP 升級到 64 位！有關更多詳細信息，請閱讀 {linkstart} 有關的說明書頁面 ↗{linkend}。",
-    "Module php-imagick in this instance has no SVG support. For better compatibility it is recommended to install it." : "本系統安裝的 php-imagick 不支援 SVG，為了更好的相容性，建議安裝它。",
-    "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running \"occ db:convert-filecache-bigint\" those pending changes could be applied manually. This operation needs to be made while the instance is offline. For further details read {linkstart}the documentation page about this ↗{linkend}." : "資料庫的有些欄位缺少 big int 格式轉換。因為欄位格式轉換需要一些時間，所以沒有自動轉換。您可以執行 \"occ db:convert-filecache-bigint\" 手動完成轉換，轉換時 Nextcloud 服務必須處於離線狀態。詳情請參閱{linkstart}關於這個問題的文件頁面 ↗{linkend}。",
-    "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "目前您的後端數據庫使用 SQLite，在大型服務當中，我們建議您使用其他的數據庫後端。",
-    "This is particularly recommended when using the desktop client for file synchronisation." : "若您使用電腦客戶端來同步檔案，非常建議您這麼做。",
-    "To migrate to another database use the command line tool: \"occ db:convert-type\", or see the {linkstart}documentation ↗{linkend}." : "要遷移到另一個數據庫，請使用指令工具：“ occ db：convert-type”，或參閱 {linkstart} 說明書↗{linkend}。",
-    "The PHP memory limit is below the recommended value of 512MB." : "目前的 PHP 的記憶體限制設定低於建議值 512MB",
-    "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:" : "某些應用程式的資料夾所有者與網頁伺服器預設用戶不同。這可能是因為您手動安裝了這些應用程式。請檢查以下應用程式資料夾的相關權限：",
-    "MySQL is used as database but does not support 4-byte characters. To be able to handle 4-byte characters (like emojis) without issues in filenames or comments for example it is recommended to enable the 4-byte support in MySQL. For further details read {linkstart}the documentation page about this ↗{linkend}." : "MySQL 用作數據庫，但不支持4-byte字符。為了能夠處理4字節字符（如表情符號）而不會出現文件名或註釋問題，建議在MySQL中啟用4字節支持。有關更多詳細信息，請參見{linkstart}關於此↗的文檔頁面{linkend}。",
-    "This instance uses an S3 based object store as primary storage. The uploaded files are stored temporarily on the server and thus it is recommended to have 50 GB of free space available in the temp directory of PHP. Check the logs for full details about the path and the available space. To improve this please change the temporary directory in the php.ini or make more space available in that path." : "此站台使用Amazon S3物件儲存為主要儲存區。上傳檔案會暫存在伺服器，因此建議PHP的暫存資料夾最少要有50GB可用容量。請在登入檔中查閱關於資料夾路徑及可用容量的詳細資訊。要增進效能，請在php.ini中變更暫存資料夾位置，或將該資料夾容量增加。",
-    "The temporary directory of this instance points to an either non-existing or non-writable directory." : "此實例的臨時目錄指向一個不存在或不可寫的目錄。",
     "You are accessing your instance over a secure connection, however your instance is generating insecure URLs. This most likely means that you are behind a reverse proxy and the overwrite config variables are not set correctly. Please read {linkstart}the documentation page about this ↗{linkend}." : "您正在通過安全連接存取實例，但是您的實例正在生成不安全的URL。這很可能意味著您被隱藏在反向代理（reverse proxy）之後，並且覆蓋配置變量（overwrite config variables）未正確設置。請閱讀{linkstart}有關此的文檔頁面↗{linkend}。",
-    "This instance is running in debug mode. Only enable this for local development and not in production environments." : "此實例以除錯模式執行。僅在近端開發且非生產環境時才啟用這個。",
     "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "您的資料目錄和檔案看來可以被公開存取。這表示 .htaccess 設定檔並未生效。我們強烈建議您設定網頁伺服器，拒絕公開存取資料目錄，或者將您的資料目錄移出網頁伺服器根目錄。",
     "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "目前 HTTP 的 {header} 標頭設定並不是 \"{expected}\" ，這是一個潛在的安全性和隱私風險，我們建議調整此項設定。",
     "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "目前 HTTP 的 {header} 標頭設定並不是 \"{expected}\" ，這將讓某些功能無法正常運作，我們建議修正此項設定。",
@@ -425,46 +393,23 @@ OC.L10N.register(
     "The \"{header}\" HTTP header is not set to \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" or \"{val5}\". This can leak referer information. See the {linkstart}W3C Recommendation ↗{linkend}." : "HTTP header “{header}” 未設置為 “ {val1}”、“ {val2}”、“{val3}”、“{val4}” 或 “{val5}”。這可能會洩漏引用資訊。請參閱 {linkstart}W3C建議↗{linkend}。",
     "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the {linkstart}security tips ↗{linkend}." : "未將 “Strict-Transport-Security” HTTP header 設置為至少“{seconds}”秒。為了增強安全性，建議按照{linkstart}安全提示↗{linkend}中的說明啟用 HSTS。",
     "Accessing site insecurely via HTTP. You are strongly advised to set up your server to require HTTPS instead, as described in the {linkstart}security tips ↗{linkend}. Without it some important web functionality like \"copy to clipboard\" or \"service workers\" will not work!" : "透過 HTTP 不安全地訪問網站。強烈建議您將伺服器設置為需要 HTTPS，如{linkstart}安全提示 ↗{linkend} 中所述。如果不這樣做，一些重要的網站功能，如「複製到剪貼板」或「服務工作者」將無法使用！。",
-    "Account name or email" : "帳戶名稱或電郵地址",
+    "Currently open" : "目前開啟",
     "Wrong username or password." : "錯誤的用戶名稱 或 密碼",
     "User disabled" : "用戶已遭停用",
+    "Login with username or email" : "以用戶名稱或電郵地址登入",
+    "Login with username" : "以用戶名稱登入",
     "Username or email" : "用戶名稱 或 電郵地址",
     "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or account name, check your spam/junk folders or ask your local administration for help." : "如果此帳戶存在，密碼重置郵件已發送到其電郵地址。如果您沒有收到，請驗證您的電郵地址和/或帳戶名，檢查您的垃圾郵件/垃圾資料夾或向您當地的管理員協助。",
-    "Start search" : "開始搜尋",
-    "Open settings menu" : "公開設定選項單",
-    "Settings" : "設定",
-    "Avatar of {fullName}" : "{fullName} 的虛擬化身",
-    "Show all contacts …" : "顯示所有聯絡人…",
-    "No files in here" : "此處沒有任何檔案",
-    "New folder" : "新資料夾",
-    "No more subfolders in here" : "沒有子資料夾",
-    "Name" : "名稱",
-    "Size" : "大小",
-    "Modified" : "已修改",
-    "\"{name}\" is an invalid file name." : "\"{name}\" 是無效的檔案名稱。",
-    "File name cannot be empty." : "檔案名稱不能為空。",
-    "\"/\" is not allowed inside a file name." : "不允許檔案名稱中出現 \"/\"。",
-    "\"{name}\" is not an allowed filetype" : "\"{name}\" 是不允許的檔案類型",
-    "{newName} already exists" : "{newName} 已經存在",
-    "Error loading file picker template: {error}" : "載入檔案選擇器模板時出錯： {error}",
+    "Apps and Settings" : "應用程式與設定",
     "Error loading message template: {error}" : "載入訊息模板時出錯： {error}",
-    "Show list view" : "顯示清單視圖",
-    "Show grid view" : "顯示網格視圖",
-    "Pending" : "待辦中",
-    "Home" : "主頁",
-    "Copy to {folder}" : "複製到 {folder}",
-    "Move to {folder}" : "移動到 {folder}",
-    "Authentication required" : "必須驗證",
-    "This action requires you to confirm your password" : "此操作需要您再次確認密碼",
-    "Confirm" : "確認",
-    "Failed to authenticate, try again" : "驗證失敗，請再試一次",
     "Users" : "用戶",
     "Username" : "用戶名稱",
     "Database user" : "數據庫用戶",
+    "This action requires you to confirm your password" : "此操作需要您再次確認密碼",
     "Confirm your password" : "確認密碼",
+    "Confirm" : "確認",
     "App token" : "應用程式權杖",
     "Alternative log in using app token" : "使用應用程式權杖來登入",
-    "Please use the command line updater because you have a big instance with more than 50 users." : "因為您有超過50名用戶，服務規模較大，請透過命令提示字元界面（command line updater）更新。",
-    "Apps and Settings" : "應用程式與設定"
+    "Please use the command line updater because you have a big instance with more than 50 users." : "因為您有超過50名用戶，服務規模較大，請透過命令提示字元界面（command line updater）更新。"
 },
 "nplurals=1; plural=0;");
