@@ -19,7 +19,6 @@ OC.L10N.register(
     "%1$s, %2$s and %3$s" : "%1$s, %2$s és %3$s",
     "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s és %4$s",
     "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s és %5$s",
-    "Education Edition" : "Oktatási kiadás",
     "Enterprise bundle" : "Vállalati csomag",
     "Groupware bundle" : "Csoportmunka csomag",
     "Hub bundle" : "Központi csomag",
@@ -36,9 +35,6 @@ OC.L10N.register(
     "The following platforms are supported: %s" : "A következő platformok támogatottak: %s",
     "Server version %s or higher is required." : "%s vagy újabb kiszolgálóverzió szükséges.",
     "Server version %s or lower is required." : "%s vagy régebbi kiszolgálóverzió szükséges.",
-    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "A bejelentkezett felhasználónak rendszergazdának vagy alrendszergazdának kell lennie, vagy speciális hozzáféréssel kell rendelkeznie ehhez a beállításhoz",
-    "Logged in user must be an admin or sub admin" : "A bejelentkezett felhasználónak rendszergazdának vagy alrendszergazgának kell lennie",
-    "Logged in user must be an admin" : "A bejelentkezett felhasználónak rendszergazdának kell lennie",
     "Wiping of device %s has started" : "A(z) %s eszköz törlése megkezdődött",
     "Wiping of device »%s« has started" : "A(z) „%s” eszköz törlése megkezdődött",
     "»%s« started remote wipe" : "„%s” elindította a távoli törlést",
@@ -79,27 +75,25 @@ OC.L10N.register(
     "seconds ago" : "pár másodperce",
     "Empty file" : "Üres fájl",
     "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "A(z) %s azonosítójú modul nem létezik. Engedélyezze az alkalmazásbeállításokban, vagy lépjen kapcsolatba a rendszergazdával.",
+    "Dot files are not allowed" : "A ponttal kezdődő fájlok nem engedélyezettek",
     "File already exists" : "A fájl már létezik",
     "Invalid path" : "Érvénytelen útvonal",
     "Failed to create file from template" : "Nem sikerült létrehozni a fájlt a sablonból",
     "Templates" : "Sablonok",
-    "File name is a reserved word" : "A fájl neve egy fenntartott szó",
-    "File name contains at least one invalid character" : "A fájlnév legalább egy érvénytelen karaktert tartalmaz",
-    "File name is too long" : "A fájlnév túl hosszú",
-    "Dot files are not allowed" : "A ponttal kezdődő fájlok nem engedélyezettek",
+    "Filename contains at least one invalid character" : "A fájlnév legalább egy érvénytelen karaktert tartalmaz",
     "Empty filename is not allowed" : "Az üres fájlnév nem engedélyezett",
     "App \"%s\" cannot be installed because appinfo file cannot be read." : "A(z) „%s” alkalmazást nem lehet telepíteni, mert az appinfo fájl nem olvasható.",
     "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "A(z) „%s” alkalmazást nem lehet telepíteni, mert nem kompatibilis ezzel a kiszolgálóverzióval.",
     "__language_name__" : "Magyar",
     "This is an automatically sent email, please do not reply." : "Ez egy automatikusan küldött levél, ne válaszoljon rá.",
-    "Help" : "Súgó",
+    "Help & privacy" : "Súgó és adatvédelem",
     "Appearance and accessibility" : "Megjelenés és akadálymentesítés",
     "Apps" : "Alkalmazások",
     "Personal settings" : "Személyes beállítások",
     "Administration settings" : "Rendszergazdai beállítások",
     "Settings" : "Beállítások",
     "Log out" : "Kijelentkezés",
-    "Users" : "Felhasználók",
+    "Accounts" : "Fiókok",
     "Email" : "E-mail",
     "Mail %s" : "Levél küldése ide: %s",
     "Fediverse" : "Födiverzum",
@@ -117,32 +111,29 @@ OC.L10N.register(
     "Headline" : "Címsor",
     "Organisation" : "Szervezet",
     "Role" : "Szerepkör",
-    "Unknown user" : "Ismeretlen felhasználó",
     "Additional settings" : "További beállítások",
-    "Enter the database username and name for %s" : "Adja meg a %s adatbázisának nevét és a hozzá tartozó felhasználónevet",
-    "Enter the database username for %s" : "Adja meg a %s adatbázisához tartozó felhasználónevet",
     "Enter the database name for %s" : "Adja meg a %s adatbázisának nevét",
     "You cannot use dots in the database name %s" : "A(z) %s adatbázisnév nem tartalmazhat pontot",
-    "MySQL username and/or password not valid" : "A MySQL felhasználónév vagy jelszó érvénytelen",
     "You need to enter details of an existing account." : "Egy már létező fiók adatait kell megadnia.",
     "Oracle connection could not be established" : "Az Oracle kapcsolat nem hozható létre",
-    "Oracle username and/or password not valid" : "Az Oracle felhasználónév vagy jelszó érvénytelen",
-    "PostgreSQL username and/or password not valid" : "A PostgreSQL felhasználói név vagy jelszó érvénytelen",
     "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "A Mac OS X nem támogatott, és a %s nem lesz teljesen működőképes. Csak saját felelősségre használja.",
     "For the best results, please consider using a GNU/Linux server instead." : "A legjobb eredmény érdekében érdemes GNU/Linux kiszolgálót használni.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Úgy tűnik, hogy ez a %s példány 32 bites PHP környezetben fut, és az open_basedir be lett állítva a php.ini fájlban. Ez 4 GB-nál nagyobb fájlok esetén problémákat okozhat, így erősen ellenjavallott.",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Távolítsa el az open_basedir beállítást a php.ini fájlból, vagy váltson 64 bites PHP-ra.",
-    "Set an admin username." : "Állítson be egy rendszergazdai felhasználónevet.",
     "Set an admin password." : "Állítson be egy rendszergazdai jelszót.",
     "Cannot create or write into the data directory %s" : "Nem létre létrehozni vagy beleírni a(z) %s adatkönyvtárba",
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "A(z) %s megosztási alrendszernek meg kell valósítania az OCP\\Share_Backend interfészt",
     "Sharing backend %s not found" : "A(z) %s megosztási alrendszer nem található",
     "Sharing backend for %s not found" : "A(z) %s megosztási alrendszere nem található",
+    "%1$s shared »%2$s« with you" : "%1$s megosztotta Önnel: „%2$s”",
+    "%1$s shared »%2$s« with you." : "%1$s megosztotta Önnel: „%2$s”.",
+    "Click the button below to open it." : "Kattintson a lenti gombra a megnyitáshoz.",
+    "Open »%s«" : "A(z) „%s” megnyitása",
+    "%1$s via %2$s" : "%1$s – %2$s",
     "%1$s shared »%2$s« with you and wants to add:" : "%1$s megosztotta Önnel: „%2$s”, és hozzá akarja adni:",
     "%1$s shared »%2$s« with you and wants to add" : "%1$s megosztotta Önnel: „%2$s”, és hozzá akarja adni",
     "»%s« added a note to a file shared with you" : "„%s” megjegyzést fűzött az Önnel megosztott fájlhoz",
-    "Open »%s«" : "A(z) „%s” megnyitása",
-    "%1$s via %2$s" : "%1$s – %2$s",
+    "Unknown share type" : "Ismeretlen megosztástípus",
     "You are not allowed to share %s" : "Nincs jogosultsága a(z) %s megosztásához",
     "Cannot increase permissions of %s" : "A(z) %s engedélyei nem bővíthetők",
     "Files cannot be shared with delete permissions" : "A fájlok nem oszthatók meg törlési jogosultsággal",
@@ -150,10 +141,6 @@ OC.L10N.register(
     "Expiration date is in the past" : "A lejárati dátum már elmúlt",
     "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Nem állítható be %n napnál távolabbi lejárati dátum","Nem állítható be %n napnál távolabbi lejárati dátum"],
     "Sharing is only allowed with group members" : "A megosztás csak a csoport tagjaival engedélyezett",
-    "Sharing %s failed, because this item is already shared with user %s" : "A(z) %s megosztása nem sikerült, mert ez az elem már meg van osztva a(z) %s felhasználóval",
-    "%1$s shared »%2$s« with you" : "%1$s megosztotta Önnel: „%2$s”",
-    "%1$s shared »%2$s« with you." : "%1$s megosztotta Önnel: „%2$s”.",
-    "Click the button below to open it." : "Kattintson a lenti gombra a megnyitáshoz.",
     "The requested share does not exist anymore" : "A kért megosztás már nem létezik",
     "The requested share comes from a disabled user" : "A kért megosztás letiltott felhasználótól származik",
     "The user was not created because the user limit has been reached. Check your notifications to learn more." : "A felhasználó nem jött létre, mert elérte a felhasználókorlátot. Nézze meg az értesítéseit, hogy többet tudjon meg.",
@@ -204,14 +191,6 @@ OC.L10N.register(
     "Nov." : "Nov.",
     "Dec." : "Dec.",
     "A valid password must be provided" : "Érvényes jelszót kell megadnia",
-    "The username is already being used" : "Ez a felhasználónév már foglalt",
-    "Could not create user" : "Nem sikerült létrehozni a felhasználót",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "A felhasználónévben csak a következő karakterek engedélyezettek: „a-z”, „A-Z”, „0-9”, szóköz és „_.@-'”",
-    "A valid username must be provided" : "Érvényes felhasználónevet kell megadnia",
-    "Username contains whitespace at the beginning or at the end" : "A felhasználónév szóközt tartalmaz az elején vagy a végén",
-    "Username must not consist of dots only" : "A felhasználónév nem állhat csak pontokból",
-    "Username is invalid because files already exist for this user" : "A felhasználónév érvénytelen, mert már vannak fájlok ehhez a felhasználóhoz",
-    "User disabled" : "Felhasználó letiltva",
     "Login canceled by app" : "Bejelentkezés megszakítva az alkalmazás által",
     "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "A(z) „%1$s” alkalmazást nem lehet telepíteni, mert a következő függőségek nem teljesülnek: %2$s",
     "a safe home for all your data" : "egy biztonságos hely az adataidnak",
@@ -244,12 +223,9 @@ OC.L10N.register(
     "Please ask your server administrator to restart the web server." : "Kérje meg a rendszergazdát, hogy indítsa újra a webkiszolgálót.",
     "The required %s config variable is not configured in the config.php file." : "A szükséges %s konfigurációs változó nincs beállítva a config.php fájlban.",
     "Please ask your server administrator to check the Nextcloud configuration." : "Kérje meg a rendszergazdát, hogy ellenőrizze a Nextcloud konfigurációját.",
-    "Your data directory is readable by other users." : "Az adatkönyvtára más felhasználók által is olvasható.",
-    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Módosítsa a könyvtár elérhetőségi engedélybeállítását 0770-re, hogy a tartalmát más felhasználók ne listázhassák.",
     "Your data directory must be an absolute path." : "Az adatkönyvtárnak abszolút útvonalnak kell lennie",
     "Check the value of \"datadirectory\" in your configuration." : "Ellenőrizze a „datadirectory” értékét a konfigurációban.",
     "Your data directory is invalid." : "Az adatkönyvtár érvénytelen.",
-    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Győződjön meg róla, hogy az adatmappa gyökerében van-e egy „.ocdata” fájl.",
     "Action \"%s\" not supported or implemented." : "A(z) „%s” művelet nem támogatott vagy nem ismert.",
     "Authentication failed, wrong token or provider ID given" : "Hitelesítés sikertelen, hibás token vagy szolgáltatóazonosító lett megadva",
     "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "A következő paraméterek hiányoznak, hogy végrehajtható legyen a kérés. Paraméterek: \"%s\"",
@@ -261,20 +237,46 @@ OC.L10N.register(
     "Storage connection error. %s" : "Tároló kapcsolódási hiba. %s",
     "Storage is temporarily not available" : "A tároló átmenetileg nem érhető el",
     "Storage connection timeout. %s" : "Időtúllépés a tárolókapcsolatban. %s",
+    "Prompt" : "Promtp",
+    "Generates a possible headline for a text." : "Egy lehetséges címsort állít elő egy szöveghez.",
+    "Summarize" : "Összesítés",
+    "Summary" : "Összefoglalás",
+    "Extract topics" : "Témák kinyerése",
+    "Translate" : "Lefordítás",
+    "Target language" : "Célnyelv",
+    "Result" : "Eredmény",
     "Free prompt" : "Szabad prompt",
     "Runs an arbitrary prompt through the language model." : "Tetszőleges promptot futtat a nyelvi modellen.",
     "Generate headline" : "Címsor előállítása",
-    "Generates a possible headline for a text." : "Egy lehetséges címsort állít elő egy szöveghez.",
-    "Summarize" : "Összesítés",
     "Summarizes text by reducing its length without losing key information." : "Összesíti a szöveget a hosszúság csökkentésével anélkül, hogy a kulcsinformációk elvesznének.",
-    "Extract topics" : "Témák kinyerése",
     "Extracts topics from a text and outputs them separated by commas." : "Kinyeri a témákat a szövegből, és vesszőkkel elválasztva megjeleníti.",
-    "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "A(z) %1$s alkalmazás fájljait helytelenül cserélték le. Ellenőrizze, hogy a verzió kompatibilis-e a kiszolgálóval.",
-    "404" : "404",
-    "Full name" : "Teljes név",
-    "libxml2 2.7.0 is at least required. Currently %s is installed." : "Legalább libxml2 2.7.0 szükséges. Jelenleg telepített: %s.",
-    "To fix this issue update your libxml2 version and restart your web server." : "A probléma javításához frissítse a libxml2 verziót, és indítsa újra a webkiszolgálót.",
-    "PostgreSQL >= 9 required." : "PostgreSQL >= 9 szükséges.",
-    "Please upgrade your database version." : "Frissítse az adatbázis verzióját."
+    "Education Edition" : "Oktatási kiadás",
+    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "A bejelentkezett felhasználónak rendszergazdának vagy alrendszergazdának kell lennie, vagy speciális hozzáféréssel kell rendelkeznie ehhez a beállításhoz",
+    "Logged in user must be an admin or sub admin" : "A bejelentkezett felhasználónak rendszergazdának vagy alrendszergazgának kell lennie",
+    "Logged in user must be an admin" : "A bejelentkezett felhasználónak rendszergazdának kell lennie",
+    "File name is a reserved word" : "A fájl neve egy fenntartott szó",
+    "File name contains at least one invalid character" : "A fájlnév legalább egy érvénytelen karaktert tartalmaz",
+    "File name is too long" : "A fájlnév túl hosszú",
+    "Help" : "Súgó",
+    "Users" : "Felhasználók",
+    "Unknown user" : "Ismeretlen felhasználó",
+    "Enter the database username and name for %s" : "Adja meg a %s adatbázisának nevét és a hozzá tartozó felhasználónevet",
+    "Enter the database username for %s" : "Adja meg a %s adatbázisához tartozó felhasználónevet",
+    "MySQL username and/or password not valid" : "A MySQL felhasználónév vagy jelszó érvénytelen",
+    "Oracle username and/or password not valid" : "Az Oracle felhasználónév vagy jelszó érvénytelen",
+    "PostgreSQL username and/or password not valid" : "A PostgreSQL felhasználói név vagy jelszó érvénytelen",
+    "Set an admin username." : "Állítson be egy rendszergazdai felhasználónevet.",
+    "Sharing %s failed, because this item is already shared with user %s" : "A(z) %s megosztása nem sikerült, mert ez az elem már meg van osztva a(z) %s felhasználóval",
+    "The username is already being used" : "Ez a felhasználónév már foglalt",
+    "Could not create user" : "Nem sikerült létrehozni a felhasználót",
+    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "A felhasználónévben csak a következő karakterek engedélyezettek: „a-z”, „A-Z”, „0-9”, szóköz és „_.@-'”",
+    "A valid username must be provided" : "Érvényes felhasználónevet kell megadnia",
+    "Username contains whitespace at the beginning or at the end" : "A felhasználónév szóközt tartalmaz az elején vagy a végén",
+    "Username must not consist of dots only" : "A felhasználónév nem állhat csak pontokból",
+    "Username is invalid because files already exist for this user" : "A felhasználónév érvénytelen, mert már vannak fájlok ehhez a felhasználóhoz",
+    "User disabled" : "Felhasználó letiltva",
+    "Your data directory is readable by other users." : "Az adatkönyvtára más felhasználók által is olvasható.",
+    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Módosítsa a könyvtár elérhetőségi engedélybeállítását 0770-re, hogy a tartalmát más felhasználók ne listázhassák.",
+    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Győződjön meg róla, hogy az adatmappa gyökerében van-e egy „.ocdata” fájl."
 },
 "nplurals=2; plural=(n != 1);");
