@@ -19,10 +19,11 @@ OC.L10N.register(
     "%1$s, %2$s and %3$s" : "%1$s, %2$s e %3$s",
     "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s e %4$s",
     "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s e %5$s",
-    "Education Edition" : "Edição Educativa",
+    "Education bundle" : "Pacote educacional",
     "Enterprise bundle" : "Pacote Enterprise",
     "Groupware bundle" : "Pacote Groupware",
     "Hub bundle" : "Pacote de hub",
+    "Public sector bundle" : "Pacote do setor público",
     "Social sharing bundle" : "Pacote de compartilhamento social",
     "PHP %s or higher is required." : "PHP %s ou superior é necessário.",
     "PHP with a version lower than %s is required." : "É necessária uma versão PHP mais antiga que a %s.",
@@ -36,9 +37,10 @@ OC.L10N.register(
     "The following platforms are supported: %s" : "As seguintes plataformas são suportadas: %s",
     "Server version %s or higher is required." : "É requerido um servidor da versão %s ou superior.",
     "Server version %s or lower is required." : "É requerido um servidor da versão %s ou abaixo.",
-    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "O usuário conectado deve ser um administrador, um subadministrador ou ter direito especial para acessar esta configuração",
-    "Logged in user must be an admin or sub admin" : "O usuário conectado deve ser um administrador ou subadministrador",
-    "Logged in user must be an admin" : "O usuário conectado deve ser um administrador",
+    "Logged in account must be an admin, a sub admin or gotten special right to access this setting" : "A conta conectada deve ser um administrador, um subadministrador ou ter direito especial para acessar esta configuração",
+    "Your current IP address doesn’t allow you to perform admin actions" : "Seu endereço IP atual não permite que você execute ações administrativas",
+    "Logged in account must be an admin or sub admin" : "A conta conectada deve ser de um administrador ou subadministrador",
+    "Logged in account must be an admin" : "A conta logada deve ser de um administrador",
     "Wiping of device %s has started" : "Limpeza do dispositivo %s iniciou",
     "Wiping of device »%s« has started" : "A limpeza do dispositivo »%s« terminou",
     "»%s« started remote wipe" : "»%s« iniciou a limpeza remota",
@@ -79,27 +81,34 @@ OC.L10N.register(
     "seconds ago" : "segundos atrás",
     "Empty file" : "Arquivo vazio",
     "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "O módulo com a ID: %s não existe. Por favor, habilite-o nas configurações de seu aplicativo ou contacte o administrador.",
+    "Dot files are not allowed" : "Arquivos Dot não são permitidos",
+    "\"%1$s\" is a forbidden file or folder name." : "\"%1$s\" é um nome de arquivo ou pasta proibido.",
+    "\"%1$s\" is a forbidden prefix for file or folder names." : "\"%1$s\" é um prefixo proibido para nomes de arquivos ou pastas.",
+    "\"%1$s\" is not allowed inside a file or folder name." : "\"%1$s\" não é permitido dentro de um nome de arquivo ou pasta.",
+    "\"%1$s\" is a forbidden file type." : "\"%1$s\" é um tipo de arquivo proibido.",
+    "Filenames must not end with \"%1$s\"." : "Os nomes dos arquivos não devem terminar com \"%1$s\".",
+    "Invalid parent path" : "Caminho mãe inválido",
     "File already exists" : "O arquivo já existe",
     "Invalid path" : "Diretório inválido",
     "Failed to create file from template" : "Falha ao criar arquivo do modelo ",
     "Templates" : "Modelos ",
-    "File name is a reserved word" : "O nome do arquivo é uma palavra reservada",
-    "File name contains at least one invalid character" : "O nome do arquivo contém pelo menos um caracter inválido",
-    "File name is too long" : "O nome do arquivo é muito longo",
-    "Dot files are not allowed" : "Arquivos Dot não são permitidos",
+    "Path contains invalid segments" : "O caminho contém segmentos inválidos",
+    "Filename is a reserved word" : "Nome do arquivo é uma palavra reservada",
+    "Filename contains at least one invalid character" : "O nome do arquivo contém pelo menos um caractere inválido  ",
+    "Filename is too long" : "O nome do arquivo é muito longo",
     "Empty filename is not allowed" : "Nome vazio para arquivo não é permitido.",
     "App \"%s\" cannot be installed because appinfo file cannot be read." : "O aplicativo \"%s\" não pode ser instalado pois o arquivo appinfo não pôde ser lido.",
     "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "O aplicativo \"%s\" não pode ser instalado pois não é compatível com a versão do servidor.",
     "__language_name__" : "Português Brasileiro",
     "This is an automatically sent email, please do not reply." : "Este e-mail é enviado automaticamente. Por favor, não responda.",
-    "Help" : "Ajuda",
+    "Help & privacy" : "Ajuda & privacidade",
     "Appearance and accessibility" : "Aparência e acessibilidade",
     "Apps" : "Aplicativos",
     "Personal settings" : "Configurações pessoais",
     "Administration settings" : "Configurações de administração",
     "Settings" : "Configurações",
     "Log out" : "Sair",
-    "Users" : "Usuários",
+    "Accounts" : "Contas",
     "Email" : "E-mail",
     "Mail %s" : "E-Mail %s",
     "Fediverse" : "Fediverse",
@@ -117,32 +126,36 @@ OC.L10N.register(
     "Headline" : "Título ",
     "Organisation" : "Organização",
     "Role" : "Função",
-    "Unknown user" : "Usuário desconhecido",
+    "Unknown account" : "Conta desconhecida",
     "Additional settings" : "Configurações adicionais",
-    "Enter the database username and name for %s" : "Digite o nome de usuário e o nome do banco de dados para %s",
-    "Enter the database username for %s" : "Digite o nome de usuário do banco de dados para %s",
+    "Enter the database Login and name for %s" : "Insira o login e o nome do banco de dados para %s",
+    "Enter the database Login for %s" : "Insira o login do banco de dados para %s",
     "Enter the database name for %s" : "Digite o nome do banco de dados para %s",
     "You cannot use dots in the database name %s" : "Você não pode usar pontos no nome do banco de dados %s",
-    "MySQL username and/or password not valid" : "Nome de usuário e/ou senha do MySQL inválidos",
+    "MySQL Login and/or password not valid" : "Login e/ou senha do MySQL inválidos",
     "You need to enter details of an existing account." : "Você necessita entrar detalhes de uma conta existente.",
     "Oracle connection could not be established" : "Conexão Oracle não pôde ser estabelecida",
-    "Oracle username and/or password not valid" : "Nome de usuário e/ou senha Oracle inválidos",
-    "PostgreSQL username and/or password not valid" : "Nome de usuário e/ou senha PostgreSQL inválidos",
+    "Oracle Login and/or password not valid" : "Login e/ou senha Oracle inválidos",
+    "PostgreSQL Login and/or password not valid" : "Login e/ou senha do PostgreSQL inválidos",
     "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X não é suportado e %s não funcionará corretamente nesta plataforma. Use-o por sua conta e risco!",
     "For the best results, please consider using a GNU/Linux server instead." : "Para obter melhores resultados, por favor considere o uso de um servidor GNU/Linux em seu lugar.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Aparentemente a instância %s está rodando em um ambiente PHP de 32 bits e o open_basedir foi configurado no php.ini. Isto pode gerar problemas com arquivos maiores que 4GB e é altamente não recomendável.",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Por favor, remova a configuração de open_basedir de seu php.ini ou mude o PHP para 64bit.",
-    "Set an admin username." : "Defina um nome do usuário administrador.",
+    "Set an admin Login." : "Defina um login de administrador.",
     "Set an admin password." : "Defina uma senha para o administrador.",
     "Cannot create or write into the data directory %s" : "Não foi possível criar ou escrever no diretório de dados %s",
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "A plataforma de compartilhamento %s deve implementar a interface OCP\\Share_Backend",
     "Sharing backend %s not found" : "Plataforma de serviço de compartilhamento %s não encontrada",
     "Sharing backend for %s not found" : "Plataforma  de compartilhamento para %s não foi encontrada",
+    "%1$s shared »%2$s« with you" : "%1$s compartilhou »%2$s« com você",
+    "%1$s shared »%2$s« with you." : "%1$s compartilhou »%2$s« com você.",
+    "Click the button below to open it." : "Clique no botão abaixo para abri-lo.",
+    "Open »%s«" : "Abrir »%s«",
+    "%1$s via %2$s" : "%1$s via %2$s",
     "%1$s shared »%2$s« with you and wants to add:" : "%1$s compartilhou »%2$s« com você e quer adicionar:",
     "%1$s shared »%2$s« with you and wants to add" : "%1$s compartilhou »%2$s« com você e quer adicionar",
     "»%s« added a note to a file shared with you" : "»%s« adicionou uma anotação num arquivo compartilhado com você",
-    "Open »%s«" : "Abrir »%s«",
-    "%1$s via %2$s" : "%1$s via %2$s",
+    "Unknown share type" : "Tipo de compartilhamento desconhecido",
     "You are not allowed to share %s" : "Você não tem permissão para compartilhar %s",
     "Cannot increase permissions of %s" : "Não foi possível aumentar as permissões de %s",
     "Files cannot be shared with delete permissions" : "Arquivos não podem ser compartilhados com permissões de exclusão",
@@ -150,14 +163,13 @@ OC.L10N.register(
     "Expiration date is in the past" : "Data de expiração está no passado",
     "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Não foi possível definir a data de expiração superior que %n dias no futuro","Não foi possível definir a data de expiração superior que %n dias no futuro","Não foi possível definir a data de expiração superior que %n dias no futuro"],
     "Sharing is only allowed with group members" : "O compartilhamento só é permitido com membros do grupo ",
-    "Sharing %s failed, because this item is already shared with user %s" : "Compartilhamento %s falhou, porque este item já está compartilhado com o usuário %s",
-    "%1$s shared »%2$s« with you" : "%1$s compartilhou »%2$s« com você",
-    "%1$s shared »%2$s« with you." : "%1$s compartilhou »%2$s« com você.",
-    "Click the button below to open it." : "Clique no botão abaixo para abri-lo.",
+    "Sharing %s failed, because this item is already shared with the account %s" : "Falha no compartilhamento %s porque este item já está compartilhado com a conta %s",
     "The requested share does not exist anymore" : "O compartilhamento solicitado não existe mais",
     "The requested share comes from a disabled user" : "O compartilhamento solicitado vem de um usuário desabilitado",
     "The user was not created because the user limit has been reached. Check your notifications to learn more." : "O usuário não foi criado porque o limite de usuários foi atingido. Confira suas notificações para saber mais.",
     "Could not find category \"%s\"" : "Impossível localizar a categoria \"%s\"",
+    "Input text" : "Entrada de texto",
+    "The input text" : "O texto de entrada",
     "Sunday" : "Domingo",
     "Monday" : "Segunda-feira",
     "Tuesday" : "Terça-feira",
@@ -204,14 +216,14 @@ OC.L10N.register(
     "Nov." : "Nov.",
     "Dec." : "Dez.",
     "A valid password must be provided" : "Uma senha válida deve ser fornecida",
-    "The username is already being used" : "Este nome de usuário já está em uso",
-    "Could not create user" : "Não foi possível criar o usuário",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Apenas os seguintes caracteres são permitidos em um nome de usuário: \"a-z\", \"A-Z\", \"0-9\", espaços e \"_.@-'\"",
-    "A valid username must be provided" : "Um nome de usuário válido deve ser fornecido",
-    "Username contains whitespace at the beginning or at the end" : "O nome de usuário contém espaço em branco no início ou no fim",
-    "Username must not consist of dots only" : "Nome do usuário não pode consistir de pontos somente",
-    "Username is invalid because files already exist for this user" : "O nome de usuário é inválido porque já exstem arquivos para este usuário",
-    "User disabled" : "Usuário desativado",
+    "The Login is already being used" : "O Login já está sendo usado",
+    "Could not create account" : "Não foi possível criar a conta",
+    "Only the following characters are allowed in an Login: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Somente os seguintes caracteres são permitidos em um Login: \"a-z\", \"A-Z\", \"0-9\", espaços e \"_.@-'\"",
+    "A valid Login must be provided" : "Um login válido deve ser fornecido",
+    "Login contains whitespace at the beginning or at the end" : "O login contém espaços em branco no início ou no final",
+    "Login must not consist of dots only" : "O login não deve consistir apenas em pontos",
+    "Login is invalid because files already exist for this user" : "O login é inválido porque já existem arquivos para este usuário",
+    "Account disabled" : "Conta desativada",
     "Login canceled by app" : "Login cancelado pelo aplicativo",
     "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "O aplicativo \"%1$s\" não pode ser instalado devido à estas dependências: %2$s",
     "a safe home for all your data" : "Um lar seguro para todos os seus dados",
@@ -244,12 +256,12 @@ OC.L10N.register(
     "Please ask your server administrator to restart the web server." : "Por favor peça ao administrador do servidor para reiniciar o servidor web.",
     "The required %s config variable is not configured in the config.php file." : "A variável %s de configuração necessária não está configurada no arquivo config.php.",
     "Please ask your server administrator to check the Nextcloud configuration." : "Peça ao administrador do servidor para verificar a configuração do Nextcloud.",
-    "Your data directory is readable by other users." : "Seu diretório de dados pode ser lido por outros usuários.",
-    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Por favor altere as permissões para 0770 para que o diretório não possa ser lido por outros usuários.",
+    "Your data directory is readable by other people." : "Seu diretório de dados pode ser lido por outras pessoas.",
+    "Please change the permissions to 0770 so that the directory cannot be listed by other people." : "Altere as permissões para 0770 para que o diretório não possa ser listado por outras pessoas.",
     "Your data directory must be an absolute path." : "Seu diretório de dados deve ser um caminho absoluto.",
     "Check the value of \"datadirectory\" in your configuration." : "Verifique o valor de \"datadirectory\" em sua configuração.",
     "Your data directory is invalid." : "Seu diretório de dados é inválido.",
-    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Assegure-se que exista um arquivo chamado \".ocdata\" na raiz do diretório \"data\".",
+    "Ensure there is a file called \"%1$s\" in the root of the data directory. It should have the content: \"%2$s\"" : "Certifique-se de que há um arquivo chamado \"%1$s\" na raiz do diretório de dados. Ele deve ter o conteúdo: \"%2$s\"",
     "Action \"%s\" not supported or implemented." : "Ação \"%s\" não suportada ou implementada.",
     "Authentication failed, wrong token or provider ID given" : "Falha na autenticação, token ou ID do provedor errados",
     "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "Parâmetros ausentes para concluir a solicitação: \"%s\"",
@@ -261,20 +273,119 @@ OC.L10N.register(
     "Storage connection error. %s" : "Erro na conexão de armazenamento. %s",
     "Storage is temporarily not available" : "Armazenamento temporariamente indisponível",
     "Storage connection timeout. %s" : "Atingido o tempo limite de conexão ao armazenamento. %s",
+    "Transcribe audio" : "Transcrever áudio",
+    "Transcribe the things said in an audio" : "Transcreva as coisas ditas em um áudio",
+    "Audio input" : "Entrada de áudio",
+    "The audio to transcribe" : "O áudio a ser transcrito",
+    "Transcription" : "Transcrição",
+    "The transcribed text" : "O texto transcrito",
+    "Context write" : "Gravação de contexto",
+    "Writes text in a given style based on the provided source material." : "Escreve texto em um determinado estilo com base no material de origem fornecido.",
+    "Writing style" : "Estilo de escrita",
+    "Demonstrate a writing style that you would like to immitate" : "Demonstre um estilo de escrita que você gostaria de imitar",
+    "Source material" : "Material de origem",
+    "The content that would like to be rewritten in the new writing style" : "O conteúdo que gostaria de ser reescrito no novo estilo de escrita",
+    "Generated text" : "Texto gerado",
+    "The generated text with content from the source material in the given style" : "O texto gerado com conteúdo do material de origem no estilo determinado",
+    "Emoji generator" : "Gerador de emojis",
+    "Takes text and generates a representative emoji for it." : "Pega texto e gera um emoji representativo para ele.",
+    "The text to generate an emoji for" : "O texto para gerar um emoji para",
+    "Generated emoji" : "Emoji gerado",
+    "The generated emoji based on the input text" : "O emoji gerado com base no texto de entrada",
+    "Generate image" : "Gerar imagem",
+    "Generate an image from a text prompt" : "Gere uma imagem a partir de um prompt de texto",
+    "Prompt" : "Pronto",
+    "Describe the image you want to generate" : "Descreva a imagem que você deseja gerar",
+    "Number of images" : "Número de imagens",
+    "How many images to generate" : "Quantas imagens gerar",
+    "Output images" : "Imagens de saída",
+    "The generated images" : "As imagens geradas",
+    "Free text to text prompt" : "Texto livre para prompt de texto",
+    "Runs an arbitrary prompt through a language model that returns a reply" : "Usa um modelo de linguagem para gerar uma resposta a partir de um prompt.",
+    "Describe a task that you want the assistant to do or ask a question" : "Descreva uma tarefa que você deseja que o assistente execute ou faça uma pergunta",
+    "Generated reply" : "Resposta gerada",
+    "The generated text from the assistant" : "O texto gerado do assistente",
+    "Chat" : "Conversa",
+    "Chat with the assistant" : "Converse com o assistente",
+    "System prompt" : "Prompt do sistema",
+    "Define rules and assumptions that the assistant should follow during the conversation." : "Defina regras e suposições que o assistente deve seguir durante a conversa.",
+    "Chat message" : "Mensagem de bate-papo",
+    "Chat history" : "Histórico de bate-papo",
+    "The history of chat messages before the current message, starting with a message by the user" : "O histórico de mensagens de bate-papo antes da mensagem atual, começando com uma mensagem do usuário",
+    "Response message" : "Mensagem de resposta",
+    "The generated response as part of the conversation" : "A resposta gerada como parte da conversa",
+    "Formalize text" : "Formalizar texto",
+    "Takes a text and makes it sound more formal" : "Pega um texto e faz com que ele soe mais formal",
+    "Write a text that you want the assistant to formalize" : "Escreva um texto que você deseja que o assistente formalize",
+    "Formalized text" : "Texto formalizado",
+    "The formalized text" : "O texto formalizado",
+    "Generate a headline" : "Gere um título",
+    "Generates a possible headline for a text." : "Gera um título possível para um texto.",
+    "Original text" : "Texto original",
+    "The original text to generate a headline for" : "O texto original para gerar um título para",
+    "The generated headline" : "O título gerado",
+    "Reformulate text" : "Reformular texto",
+    "Takes a text and reformulates it" : "Pega um texto e o reformula",
+    "Write a text that you want the assistant to reformulate" : "Escrever um texto que você deseja que o assistente reformule",
+    "Reformulated text" : "Texto reformulado",
+    "The reformulated text, written by the assistant" : "O texto reformulado, escrito pela assistente",
+    "Simplify text" : "Simplificar texto",
+    "Takes a text and simplifies it" : "Pegar um texto e simplificar ",
+    "Write a text that you want the assistant to simplify" : "Escreva um texto que você deseja que o assistente simplifique",
+    "Simplified text" : "Texto simplificado",
+    "The simplified text" : "O texto simplificado",
+    "Summarize" : "Resumir",
+    "Summarizes a text" : "Resumir um texto",
+    "The original text to summarize" : "O texto original para resumir",
+    "Summary" : "Resumo",
+    "The generated summary" : "O resumo gerado",
+    "Extract topics" : "Extrair tópicos",
+    "Extracts topics from a text and outputs them separated by commas" : "Extrai tópicos de um texto e os exibe separados por vírgulas",
+    "The original text to extract topics from" : "O texto original para extrair tópicos de",
+    "Topics" : "Tópicos",
+    "The list of extracted topics" : "A lista de tópicos extraídos",
+    "Translate" : "Traduzir",
+    "Translate text from one language to another" : "Traduzir o texto de um idioma para outro",
+    "Origin text" : "Texto original",
+    "The text to translate" : "O texto a ser traduzido",
+    "Origin language" : "Idioma original",
+    "The language of the origin text" : "O idioma do texto original",
+    "Target language" : "Target language",
+    "The desired language to translate the origin text in" : "O idioma definido para traduzir o texto original",
+    "Result" : "Resultado",
+    "The translated text" : "O texto traduzido",
     "Free prompt" : "Solicitação gratuita",
     "Runs an arbitrary prompt through the language model." : "Executa um prompt arbitrário por meio do modelo de idioma.",
     "Generate headline" : "Gerar título",
-    "Generates a possible headline for a text." : "Gera um título possível para um texto.",
-    "Summarize" : "Resumir",
     "Summarizes text by reducing its length without losing key information." : "Resume o texto reduzindo seu comprimento sem perder informações importantes.",
-    "Extract topics" : "Extrair tópicos",
     "Extracts topics from a text and outputs them separated by commas." : "Extrai tópicos de um texto e os gera separados por vírgulas.",
-    "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "Os arquivos do aplicativo %1$s não foram instalados corretamente. Certifique-se que é uma versão compatível com seu servidor.",
-    "404" : "404",
-    "Full name" : "Nome completo ",
-    "libxml2 2.7.0 is at least required. Currently %s is installed." : "A libxml2 2.7.0 é a versão mínima necessária. Atualmente a versão %s está instalada.",
-    "To fix this issue update your libxml2 version and restart your web server." : "Para corrigir este problema, atualize a versão da sua libxml2 e reinicie seu servidor web.",
-    "PostgreSQL >= 9 required." : "PostgreSQL >= 9 é necessário.",
-    "Please upgrade your database version." : "Por favor, atualize a versão do seu banco de dados."
+    "Education Edition" : "Edição Educativa",
+    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "O usuário conectado deve ser um administrador, um subadministrador ou ter direito especial para acessar esta configuração",
+    "Logged in user must be an admin or sub admin" : "O usuário conectado deve ser um administrador ou subadministrador",
+    "Logged in user must be an admin" : "O usuário conectado deve ser um administrador",
+    "File name is a reserved word" : "O nome do arquivo é uma palavra reservada",
+    "File name contains at least one invalid character" : "O nome do arquivo contém pelo menos um caracter inválido",
+    "File name is too long" : "O nome do arquivo é muito longo",
+    "Help" : "Ajuda",
+    "Users" : "Usuários",
+    "Unknown user" : "Usuário desconhecido",
+    "Enter the database username and name for %s" : "Digite o nome de usuário e o nome do banco de dados para %s",
+    "Enter the database username for %s" : "Digite o nome de usuário do banco de dados para %s",
+    "MySQL username and/or password not valid" : "Nome de usuário e/ou senha do MySQL inválidos",
+    "Oracle username and/or password not valid" : "Nome de usuário e/ou senha Oracle inválidos",
+    "PostgreSQL username and/or password not valid" : "Nome de usuário e/ou senha PostgreSQL inválidos",
+    "Set an admin username." : "Defina um nome do usuário administrador.",
+    "Sharing %s failed, because this item is already shared with user %s" : "Compartilhamento %s falhou, porque este item já está compartilhado com o usuário %s",
+    "The username is already being used" : "Este nome de usuário já está em uso",
+    "Could not create user" : "Não foi possível criar o usuário",
+    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Apenas os seguintes caracteres são permitidos em um nome de usuário: \"a-z\", \"A-Z\", \"0-9\", espaços e \"_.@-'\"",
+    "A valid username must be provided" : "Um nome de usuário válido deve ser fornecido",
+    "Username contains whitespace at the beginning or at the end" : "O nome de usuário contém espaço em branco no início ou no fim",
+    "Username must not consist of dots only" : "Nome do usuário não pode consistir de pontos somente",
+    "Username is invalid because files already exist for this user" : "O nome de usuário é inválido porque já exstem arquivos para este usuário",
+    "User disabled" : "Usuário desativado",
+    "Your data directory is readable by other users." : "Seu diretório de dados pode ser lido por outros usuários.",
+    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Por favor altere as permissões para 0770 para que o diretório não possa ser lido por outros usuários.",
+    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Assegure-se que exista um arquivo chamado \".ocdata\" na raiz do diretório \"data\"."
 },
 "nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
